@@ -2542,7 +2542,7 @@ skip_resolved_ae2:
 				if(node->val.i >= 0)
 					{
 					char rc[AE2_MAXFACLEN+1];
-					FACREF fr;
+					AE2_FACREF fr;
 
 					fr.s = node->val.i;
 					fr.row = 0;
@@ -2690,123 +2690,3 @@ free_vars:
 	}
 }
 
-/*
- * $Id: logfile.c,v 1.36 2010/10/02 18:58:55 gtkwave Exp $
- * $Log: logfile.c,v $
- * Revision 1.36  2010/10/02 18:58:55  gtkwave
- * ctype.h compiler warning fixes (char vs int)
- *
- * Revision 1.35  2010/06/25 12:01:56  gtkwave
- * removed c++ style comment
- *
- * Revision 1.34  2010/06/23 05:40:48  gtkwave
- * added dnd from gtkwave into rtlbrowse
- *
- * Revision 1.33  2010/05/23 04:11:04  gtkwave
- * null pointer crash fixes
- *
- * Revision 1.32  2009/12/24 21:03:32  gtkwave
- * warnings fixes
- *
- * Revision 1.31  2009/07/07 20:22:52  gtkwave
- * use standard verilog capitalization for x/X z/Z values in hexify()
- *
- * Revision 1.30  2009/06/29 18:16:23  gtkwave
- * adding framework for module type annotation on inner tree nodes
- *
- * Revision 1.29  2009/06/14 15:44:29  gtkwave
- * fix fst alias handling, reduce number of hier searches for fst
- *
- * Revision 1.28  2009/06/14 01:11:11  gtkwave
- * previous match optimization fix
- *
- * Revision 1.27  2009/06/13 22:02:18  gtkwave
- * beginning to add FST support to rtlbrowse
- *
- * Revision 1.26  2009/06/12 19:50:08  gtkwave
- * optimize out duplicate fac finding by adding a field to jrb tree
- *
- * Revision 1.25  2009/04/24 04:24:22  gtkwave
- * reload and cygwin fixes for rtlbrowse
- *
- * Revision 1.24  2008/12/26 22:15:42  gtkwave
- * compile fixes for gtk+-2.0 (old versions of gtk2)
- *
- * Revision 1.23  2008/12/24 04:17:09  gtkwave
- * added highlighting to tab close buttons in rtlbrowse
- *
- * Revision 1.22  2008/12/20 05:45:03  gtkwave
- * gtk1 compatibility and -Wshadow warning fixes
- *
- * Revision 1.21  2008/11/24 03:26:52  gtkwave
- * warnings cleanups
- *
- * Revision 1.20  2008/11/19 16:34:26  gtkwave
- * removed strcasestr and use strstr with toupper()
- *
- * Revision 1.19  2008/11/18 23:23:08  gtkwave
- * added search capability to rtlbrowse
- *
- * Revision 1.18  2008/11/18 06:40:35  gtkwave
- * removed unnecessary buffer deletion
- *
- * Revision 1.17  2008/11/18 05:37:34  gtkwave
- * code cleanups
- *
- * Revision 1.16  2008/11/18 04:15:26  gtkwave
- * prelim support for text searching in rtlbrowse
- *
- * Revision 1.15  2008/11/17 22:36:14  gtkwave
- * adding find widgets
- *
- * Revision 1.14  2008/11/16 02:40:05  gtkwave
- * do bounds checking for close button release in bounds for tabs
- *
- * Revision 1.13  2008/11/16 02:17:47  gtkwave
- * rtlbrowse updates for single integrated window
- *
- * Revision 1.12  2008/11/13 00:12:01  gtkwave
- * allow d&d to move one signal even if not highlighted
- *
- * Revision 1.11  2008/11/12 19:49:42  gtkwave
- * changed usage of usize
- *
- * Revision 1.10  2008/10/06 19:22:58  gtkwave
- * more dnd logfile fixes
- *
- * Revision 1.9  2008/10/06 18:30:57  gtkwave
- * allow DnD text drag to be able to process half-highlighted signal names
- *
- * Revision 1.8  2008/10/06 17:58:03  gtkwave
- * optimize by not refreshing un-DnD'd windows
- *
- * Revision 1.7  2008/10/04 15:15:20  gtkwave
- * gtk1 compatibility fixes
- *
- * Revision 1.6  2008/10/03 20:29:33  gtkwave
- * added dnd of signals from rtlbrowse into gtkwave
- *
- * Revision 1.5  2008/06/11 08:01:40  gtkwave
- * gcc 4.3.x compiler warning fixes
- *
- * Revision 1.4  2008/02/05 07:20:24  gtkwave
- * added realtime rtlbrowse updates (follows marker at 100ms intervals)
- *
- * Revision 1.3  2008/02/04 03:48:57  gtkwave
- * rtlbrowse fix for lxt2 files
- *
- * Revision 1.2  2007/08/26 21:35:39  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.1  2007/08/06 03:50:44  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1  2007/05/30 04:25:41  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:10  gtkwave
- * initial release
- *
- */
-
