@@ -26,6 +26,7 @@
 #include "fgetdynamic.h"
 #include "debug.h"
 #include "busy.h"
+#include "hierpack.h"
 
 
 /* 
@@ -36,7 +37,7 @@
 
 const char *ae2_loader_fail_msg = "Sorry, AET2 support was not compiled into this executable, exiting.\n\n";
 
-TimeType ae2_main(char *fname, char *skip_start, char *skip_end, char *indirect_fname)
+TimeType ae2_main(char *fname, char *skip_start, char *skip_end)
 {
 fprintf(stderr, "%s", ae2_loader_fail_msg);
 exit(255);
@@ -104,41 +105,48 @@ va_end(ap);
 exit(255);
 }
 
-static char *twirler = "|/-\\";
 
 static void msg_fn(int sev, const char *format, ...)
 {
-if((!GLOBALS->ae2_msg_suppress)||(sev))
-	{
-	va_list ap;
-	va_start(ap, format);
+va_list ap;
+va_start(ap, format);
 
-	fprintf(stderr, "AE2 %03d | ", sev);
-	vfprintf(stderr, format, ap);
-	fprintf(stderr, "\n");
+fprintf(stderr, "AE2 %03d | ", sev);
+vfprintf(stderr, format, ap);
+fprintf(stderr, "\n");
 
-	va_end(ap);
-	}
-	else
-	{
-	va_list ap;
-	va_start(ap, format);
-
-	fprintf(stderr, "AE2 %03d | ", sev);
-	vfprintf(stderr, format, ap);
-	fprintf(stderr, " %c\r", twirler[GLOBALS->ae2_twirl_pos]);
-	GLOBALS->ae2_twirl_pos = (GLOBALS->ae2_twirl_pos+1) & 3;
-	GLOBALS->ae2_did_twirl = 1;
-
-	va_end(ap);
-	}
+va_end(ap);
 }
 
+#ifdef AET2_ALIASDB_IS_PRESENT
+static void adb_msg_fn(unsigned long sev, const char *format, ...)
+{
+va_list ap;
+va_start(ap, format);
+
+fprintf(stderr, "AE2 %03d | ", (unsigned int)sev);
+vfprintf(stderr, format, ap);
+fprintf(stderr, "\n");
+
+va_end(ap);
+}
+
+
+static unsigned long symbol_fn (cchar *name, void *udata)
+{
+AE2_FACREF f2;
+return(ae2_read_find_symbol(GLOBALS->ae2, name, &f2));
+}
+
+#endif
+
+
 static void *alloc_fn(size_t size)
 {        
 void *pnt = calloc_2(1, size);
 return(pnt);
 }
+
         
 static void free_fn(void* ptr, size_t size)
 {
@@ -149,22 +157,267 @@ if(ptr)
 }
 
 
+/*
+ * dynamic alias allocator (memory written to is converted to refer to facidx instead)
+ */
+#ifdef AET2_ALIASDB_IS_PRESENT
+
+static void *adb_alloc_2(size_t siz)
+{
+if(GLOBALS->adb_alloc_pool_base)
+        {
+        if((siz + GLOBALS->adb_alloc_idx) <= WAVE_ADB_ALLOC_POOL_SIZE)
+                {
+                unsigned char *m = GLOBALS->adb_alloc_pool_base + GLOBALS->adb_alloc_idx;
+                GLOBALS->adb_alloc_idx += siz;
+                return((void *)m);
+                }
+        else
+        if(siz >= WAVE_ADB_ALLOC_ALTREQ_SIZE)
+                {
+                return(calloc_2(1, siz));
+                }
+        }
+
+GLOBALS->adb_alloc_pool_base = calloc_2(1, WAVE_ADB_ALLOC_POOL_SIZE);
+GLOBALS->adb_alloc_idx = 0;
+return(adb_alloc_2(siz));
+}
+#endif
+
+
+/*
+ * dynamic alias support on reads
+ */
+#ifdef AET2_ALIASDB_IS_PRESENT
+
+static unsigned long ae2_read_symbol_rows_2(AE2_HANDLE handle, unsigned long symbol_idx)
+{
+if(symbol_idx <= GLOBALS->ae2_num_facs)
+	{
+	return(ae2_read_symbol_rows(handle, symbol_idx));
+	}
+	else
+	{
+	return(1);
+	}
+}
+
+
+static void ae2_read_value_2a(AE2_HANDLE handle, unsigned long idx, uint64_t cycle, char* value, int tot_length)
+{
+int i;
+int numTerms = GLOBALS->adb_num_terms[--idx];
+int length;
+int offs = 0;
+
+if(numTerms)
+	{
+	for(i=0;i<numTerms;i++)
+		{
+		ADB_TERM *at = &GLOBALS->adb_aliases[idx][i];
+		AE2_FACREF fr2;
+	
+		fr2.s = at->id;
+		fr2.row = 0;
+		fr2.row_high = 0;
+		fr2.offset = at->first;
+
+		if(at->last >= at->first)
+			{
+			fr2.length = length = at->last - at->first + 1;
+			}
+			else
+			{
+			fr2.length = -(length = at->first - at->last + 1);
+			}
+
+		ae2_read_value(handle, &fr2, cycle, value+offs);
+		offs += length;
+		}
+	}
+	else
+	{
+	/* should never happen */
+	memset(value, 'Z', tot_length);
+	}
+
+value[tot_length] = 0;
+}
+
+
+static uint64_t ae2_read_next_value_2a(AE2_HANDLE handle, unsigned long idx, uint64_t cycle, char* value, int tot_length)
+{
+uint64_t cyc = GLOBALS->max_time + 1;
+uint64_t t_cyc;
+int i;
+int numTerms = GLOBALS->adb_num_terms[--idx];
+int length;
+int offs = 0;
+int nonew = 0;
+
+if(numTerms)
+	{
+	for(i=0;i<numTerms;i++)
+		{
+		ADB_TERM *at = &GLOBALS->adb_aliases[idx][i];
+		AE2_FACREF fr2;
+	
+		fr2.s = at->id;
+		fr2.row = 0;
+		fr2.row_high = 0;
+		fr2.offset = at->first;
+
+		if(at->last >= at->first)
+			{
+			fr2.length = length = at->last - at->first + 1;
+			}
+			else
+			{
+			fr2.length = -(length = at->first - at->last + 1);
+			}
+		
+		t_cyc = ae2_read_next_value(handle, &fr2, cycle, value+offs); /* simply want to calculate next value change time */
+		if(t_cyc != cycle)
+			{
+			if(t_cyc < cyc) { cyc = t_cyc; }
+			}
+			else
+			{
+			nonew++;
+			}
+
+		offs += length;
+		}
+
+	if(nonew == numTerms) { cyc = cycle; }
+
+	ae2_read_value_2a(handle, idx+1, cyc, value, tot_length); /* reread at that calculated value change time */
+	}
+	else
+	{
+	/* should never happen */
+	memset(value, 'Z', tot_length);
+	value[tot_length] = 0;
+	}
+
+return(cyc);
+}
+
+
+static void ae2_read_value_2(AE2_HANDLE handle, AE2_FACREF* fr, uint64_t cycle, char* value)
+{
+if(fr->s <= GLOBALS->ae2_num_facs)
+	{
+	ae2_read_value(handle, fr, cycle, value);
+	}
+	else /* complex alias... */
+	{
+	unsigned long idx = fr->s - GLOBALS->ae2_num_facs;
+	ae2_read_value_2a(handle, idx, cycle, value, fr->length);
+	}
+}
+
+
+static uint64_t ae2_read_next_value_2(AE2_HANDLE handle, AE2_FACREF* fr, uint64_t cycle, char* value)
+{
+if(fr->s <= GLOBALS->ae2_num_facs)
+        {
+	return(ae2_read_next_value(handle, fr, cycle, value));
+	}
+	else /* complex alias... */
+	{
+	unsigned long idx = fr->s - GLOBALS->ae2_num_facs;
+	return(ae2_read_next_value_2a(handle, idx, cycle, value, fr->length));
+	}
+}
+
+#else
+
+#define ae2_read_symbol_rows_2(a,b) ae2_read_symbol_rows((a),(b))
+#define ae2_read_value_2(a,b,c,d) ae2_read_value((a),(b),(c),(d))
+#define ae2_read_next_value_2(a,b,c,d) ae2_read_next_value((a),(b),(c),(d))
+
+#endif
+
+
+/*
+ * fast itoa for decimal numbers
+ */
+static char* itoa_2(int value, char* result)
+{
+char* ptr = result, *ptr1 = result, tmp_char;
+int tmp_value;
+
+do {
+        tmp_value = value;
+        value /= 10;
+        *ptr++ = "9876543210123456789" [9 + (tmp_value - value * 10)];
+} while ( value );
+
+if (tmp_value < 0) *ptr++ = '-';
+result = ptr;
+*ptr-- = '\0';
+while(ptr1 < ptr) {
+        tmp_char = *ptr;
+        *ptr--= *ptr1;
+        *ptr1++ = tmp_char;
+}
+return(result);
+}
+
+/*
+ * preformatted sprintf statements which remove parsing latency
+ */
+static int sprintf_2_1d(char *s, int d)
+{
+char *s2 = s;
+
+*(s2++) = '[';
+*(s2++) = '0';
+*(s2++) = ':';
+s2 = itoa_2(d, s2);
+*(s2++) = ']';
+*s2 = 0;
+
+return(s2 - s);
+}
+
+#ifdef AET2_ALIASDB_IS_PRESENT
+static int sprintf_2_2d(char *s, int d1, int d2)
+{
+char *s2 = s;
+
+*(s2++) = '[';
+s2 = itoa_2(d1, s2);
+*(s2++) = ':';
+s2 = itoa_2(d2, s2);
+*(s2++) = ']';
+*s2 = 0;
+
+return(s2 - s);
+}
+#endif
+
+
 /*
  * mainline
  */
-TimeType ae2_main(char *fname, char *skip_start, char *skip_end, char *indirect_fname)
+TimeType ae2_main(char *fname, char *skip_start, char *skip_end)
 {
 int i;
 int match_idx;
 struct Node *n;
 struct symbol *s;
-FILE *ind_h = NULL;
 TimeType first_cycle, last_cycle, total_cycles;
-char *info_fname = NULL;
 int total_rows = 0;
 int mono_row_offset = 0;
 struct Node *monolithic_node = NULL;
 struct symbol *monolithic_sym = NULL;
+#ifdef AET2_ALIASDB_IS_PRESENT
+unsigned long kw = 0;
+#endif
+char buf[AE2_MAX_NAME_LENGTH+1];
 
 ae2_initialize(error_fn, msg_fn, alloc_fn, free_fn);
 
@@ -182,273 +435,126 @@ if ( (!(GLOBALS->ae2_f=fopen(fname, "rb"))) || (!(GLOBALS->ae2 = ae2_read_initia
 
 GLOBALS->time_dimension = 'n';
 
-info_fname = malloc_2(strlen(fname) + 4 + 1);
-strcpy(info_fname, fname);
-strcat(info_fname, "info");
-if ( (!(GLOBALS->ae2_info_f=fopen(info_fname, "rb"))) || (!(GLOBALS->ae2_info = ae2_read_initialize(GLOBALS->ae2_info_f))) )
+if(!GLOBALS->fast_tree_sort)
         {
-	if(GLOBALS->ae2_info_f)
-		{
-		fclose(GLOBALS->ae2_info_f);
-		GLOBALS->ae2_info_f = NULL;
-		}
-
-	/* non-null GLOBALS->ae2_info says we have annotation info available */
+        GLOBALS->do_hier_compress = 0;
         }
-	else
-	{
-	time_t m1 = ae2_read_model_timestamp(GLOBALS->ae2);
-	time_t m2 = ae2_read_model_timestamp(GLOBALS->ae2_info);
-
-	uint64_t st_1 = ae2_read_start_cycle(GLOBALS->ae2);
-	uint64_t en_1 = ae2_read_end_cycle(GLOBALS->ae2);
-
-	uint64_t st_2 = ae2_read_start_cycle(GLOBALS->ae2_info);
-	uint64_t en_2 = ae2_read_end_cycle(GLOBALS->ae2_info);
-
-	FACREF time_fr, prec_fr;
-        unsigned long time_rc = ae2_read_find_symbol(GLOBALS->ae2_info, AET2_TIMEFAC, &time_fr);
-        unsigned long prec_rc = ae2_read_find_symbol(GLOBALS->ae2_info, AET2_PRECFAC, &prec_fr);
-
-	if((m1 == m2) && (st_1 == st_2) && (en_1 == en_2) && (time_rc) && (prec_rc) & (time_fr.length == 64))
-		{
-                uint64_t i_value = 0;            
-                uint64_t timestep;
-		int bit;
-		char precstr[65];
-		unsigned int prec = 0;
-		char scale;
-
-		fprintf(stderr, AET2_RDLOAD"Using info file for extra information.\n");
-
-		ae2_read_value(GLOBALS->ae2_info, &prec_fr, st_2, precstr);
-		for(bit=0;bit<8;bit++)
-			{
-			prec <<= 1;
-			prec |= (precstr[bit]&1);
-			}
-
-		scale = (char)(prec & 0xff);
-		exponent_to_time_scale(scale);
-
-		GLOBALS->ae2_time_xlate = calloc_2(en_2 - st_2 + 1, sizeof(TimeType));
-         
-                for(timestep = st_2; timestep <= en_2; timestep++)
-                        {
-			char valstr[65];
-			uint64_t val = 0;
-			ae2_read_value(GLOBALS->ae2_info, &time_fr, timestep, valstr);
-
-			for(bit=0;bit<64;bit++)
-				{
-				val <<= 1;
-				val |= (valstr[bit]&1);
-				}
-
-			i_value += val;
-			GLOBALS->ae2_time_xlate[timestep - st_2] = i_value * GLOBALS->time_scale;
-                        }
-		}
-		else
-		{
-		ae2_read_end(GLOBALS->ae2_info); GLOBALS->ae2_info = NULL;
-		fclose(GLOBALS->ae2_info_f); GLOBALS->ae2_info_f = NULL;
-		}
-	}
-free_2(info_fname); info_fname = NULL;
 
+init_facility_pack();
 
 /* SPLASH */                            splash_create();
 
 sym_hash_initialize(GLOBALS);
-GLOBALS->ae2_num_sections=ae2_read_num_sections(GLOBALS->ae2);
-GLOBALS->numfacs=ae2_read_num_symbols(GLOBALS->ae2);
-GLOBALS->ae2_process_mask = calloc_2(1, GLOBALS->numfacs/8+1);
-#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
-GLOBALS->ae2_invert_idx = calloc_2(GLOBALS->numfacs + 1, sizeof(struct symbol *));
+
+#ifdef AET2_ALIASDB_IS_PRESENT
+if(!GLOBALS->disable_ae2_alias) { kw = ae2_read_locate_keyword(GLOBALS->ae2, "aliasdb"); }
+if(kw)
+        {
+        GLOBALS->adb_alias_stream_file = ae2_read_keyword_stream(GLOBALS->ae2, kw);
+        GLOBALS->adb = adb_open_embed(GLOBALS->adb_alias_stream_file, NULL, alloc_fn, free_fn, adb_msg_fn, error_fn);
+        if(GLOBALS->adb)
+                {
+		unsigned long fn;
+
+                GLOBALS->ae2_num_aliases = adb_num_aliases(GLOBALS->adb);
+                GLOBALS->adb_max_terms  = adb_max_alias_terms(GLOBALS->adb);
+                GLOBALS->adb_terms = calloc_2(GLOBALS->adb_max_terms + 1, sizeof(ADB_TERM));
+
+                GLOBALS->adb_aliases = calloc_2(GLOBALS->ae2_num_aliases, sizeof(ADB_TERM *));
+		GLOBALS->adb_num_terms = calloc_2(GLOBALS->ae2_num_aliases, sizeof(unsigned short));
+		GLOBALS->adb_idx_first = calloc_2(GLOBALS->ae2_num_aliases, sizeof(unsigned short));
+		GLOBALS->adb_idx_last = calloc_2(GLOBALS->ae2_num_aliases, sizeof(unsigned short));
+
+		fn = adb_map_ids (GLOBALS->adb, symbol_fn, GLOBALS->ae2); /* iteratively replaces all .id with FACIDX */
+
+		fprintf(stderr, AET2_RDLOAD"Encountered %lu aliases referencing %lu facs.\n", GLOBALS->ae2_num_aliases, fn);
+                }
+        }
 #endif
 
-if(indirect_fname)
-	{
-	ind_h = fopen(indirect_fname, "rb");
-	if(!ind_h)
-		{
-		fprintf(stderr, AET2_RDLOAD"Could not open indirect file '%s', skipping.\n", indirect_fname);
-		}
-		else
-		{
-		int added = 0;
+GLOBALS->ae2_num_sections=ae2_read_num_sections(GLOBALS->ae2);
+GLOBALS->ae2_num_facs = ae2_read_num_symbols(GLOBALS->ae2);
+GLOBALS->numfacs = GLOBALS->ae2_num_facs + GLOBALS->ae2_num_aliases;
+GLOBALS->ae2_process_mask = calloc_2(1, GLOBALS->numfacs/8+1);
 
-		fprintf(stderr, AET2_RDLOAD"Using indirect file '%s' for facility selection...\n", indirect_fname);
-		while(!feof(ind_h))
-			{
-			char *exp1, *exp2, *exp3;
-			void *regex;
-		
-			exp1 = fgetmalloc(ind_h);
-			if(!exp1) continue;
-			exp2 = exp1;
-			while(isspace(*exp2)) exp2++;
-
-			exp3 = exp2 + strlen(exp2) - 1;
-			while(exp3 != exp2)
-				{
-				if(!isspace(*exp3))				
-					{
-					*(exp3+1) = 0;
-					break;
-					}
-				exp3--;
-				}
-
-			if((*exp2)&&(*exp2!='#'))
-				{
-				regex = wave_regex_alloc_compile(exp2);
-				if(regex)
-					{
-					struct regex_links *rpnt = malloc_2(sizeof(struct regex_links));
-		
-					rpnt->pnt = regex;
-					rpnt->next = GLOBALS->ae2_regex_head;
-					GLOBALS->ae2_regex_head = rpnt;
-		
-					if(added < 31)
-						{
-						fprintf(stderr, AET2_RDLOAD"Added indirect regex '%s'\n", exp2);
-						}
-					else
-					if(added == 31)
-						{
-						fprintf(stderr, AET2_RDLOAD"Added indirect regex '%s', adding more quietly...\n", exp2);
-						}
-					added++;
-					}
-				}
-
-			free_2(exp1);
-			}
-	
-		fclose(ind_h); ind_h = NULL;
-	
-		GLOBALS->ae2_regex_matches = 0;
-		if(GLOBALS->ae2_regex_head)
-			{
-			struct regex_links *rpnt;
-	
-			for(i=0;i<GLOBALS->numfacs;i++)
-				{
-			        char buf[AE2_MAX_NAME_LENGTH+1];
-			        int idx = i+1;
-			
-			        ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
-				rpnt = GLOBALS->ae2_regex_head;
-				while(rpnt)
-					{
-					if(wave_regex_alloc_match(rpnt->pnt, buf))
-						{
-						/* fprintf(stderr, "Matched '%s'\n", buf); */
-						aet2_rd_set_fac_process_mask(i);
-						GLOBALS->ae2_regex_matches++;
-						break;
-						}
-	
-					rpnt=rpnt->next;
-					}
-				}
-	
-			rpnt = GLOBALS->ae2_regex_head;
-			while(rpnt)
-				{
-				struct regex_links *rpnt2 = rpnt->next;
-				wave_regex_alloc_free(rpnt->pnt);			
-				free_2(rpnt);
-				rpnt = rpnt2;
-				}
-	
-			GLOBALS->ae2_regex_head=NULL;
-			}
-	
-		if(GLOBALS->ae2_regex_matches)
-			{
-			fprintf(stderr, AET2_RDLOAD"Matched %d/%d facilities against indirect file.\n", GLOBALS->ae2_regex_matches, GLOBALS->numfacs);
-			}
-			else
-			{
-			fprintf(stderr, AET2_RDLOAD"Matched %d/%d facilities against indirect file, exiting.\n", GLOBALS->ae2_regex_matches, GLOBALS->numfacs);
-			exit(0); /* no need to attempt recovery via return as AE2 is valid and no sigs match */
-			}
-		}
-	}
-	else
-	{
-	if(1)
-		{
-		int early_out = 0;
-		fprintf(stderr, AET2_RDLOAD"Filtering BugSpray facilities...\n");
-		GLOBALS->ae2_regex_matches = 0;
-		for(i=0;i<GLOBALS->numfacs;i++)
-		        {
-		        char buf[AE2_MAX_NAME_LENGTH+1];
-		        int idx = i+1;
-	
-			ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
-	
-			if(buf[0] == 'B')
-				{
-				if(buf[1] == 'S')
-					{
-					if(buf[2] == '%')
-						{
-						early_out = 1;
-						continue;
-						}
-					}
-				}
-	
-			if(early_out) break;
-	
-			aet2_rd_set_fac_process_mask(i);
-			GLOBALS->ae2_regex_matches++;
-			}
-	
-		for(;i<GLOBALS->numfacs;i++)
-		        {
-			aet2_rd_set_fac_process_mask(i);
-			GLOBALS->ae2_regex_matches++;
-			}
-		}
-	}
-
-if(!GLOBALS->ae2_regex_matches)
-	{
-	GLOBALS->ae2_fr=calloc_2(GLOBALS->numfacs, sizeof(FACREF));
-	GLOBALS->ae2_lx2_table=(struct lx2_entry **)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry *));
-	}
-	else
-	{
-	GLOBALS->ae2_fr=calloc_2(GLOBALS->ae2_regex_matches, sizeof(FACREF));
-	GLOBALS->ae2_lx2_table=(struct lx2_entry **)calloc_2(GLOBALS->ae2_regex_matches, sizeof(struct lx2_entry *));
-	}
+GLOBALS->ae2_fr=calloc_2(GLOBALS->numfacs, sizeof(AE2_FACREF));
+GLOBALS->ae2_lx2_table=(struct lx2_entry **)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry *));
 
 match_idx = 0;
-for(i=0;i<GLOBALS->numfacs;i++)
+for(i=0;i<GLOBALS->ae2_num_facs;i++)
 	{
         int idx = i+1;
 
-	if((GLOBALS->ae2_regex_matches)&&(!aet2_rd_get_fac_process_mask(i))) continue;
- 
         GLOBALS->ae2_fr[match_idx].facname = NULL;
+        GLOBALS->ae2_fr[match_idx].s = idx;
         GLOBALS->ae2_fr[match_idx].row = ae2_read_symbol_rows(GLOBALS->ae2, idx);
+	if(GLOBALS->ae2_fr[match_idx].row > AE2_MAX_ROWS)
+		{
+		GLOBALS->ae2_fr[match_idx].row = AE2_MAX_ROWS;
+		ae2_read_find_symbol(GLOBALS->ae2, buf, &GLOBALS->ae2_fr[match_idx]);
+		fprintf(stderr, AET2_RDLOAD"Warning: Reduced array %s to %d rows.\n", buf, AE2_MAX_ROWS);
+		}
 	total_rows += (GLOBALS->ae2_fr[match_idx].row > 0) ? GLOBALS->ae2_fr[match_idx].row : 1;
 	if(GLOBALS->ae2_fr[match_idx].row == 1) GLOBALS->ae2_fr[match_idx].row = 0;
         GLOBALS->ae2_fr[match_idx].length = ae2_read_symbol_length(GLOBALS->ae2, idx);
-        GLOBALS->ae2_fr[match_idx].s = idx;
         GLOBALS->ae2_fr[match_idx].row_high = 0;
         GLOBALS->ae2_fr[match_idx].offset = 0;
 
 	match_idx++;
 	}
 
+#ifdef AET2_ALIASDB_IS_PRESENT
+for(i=0;i<GLOBALS->ae2_num_aliases;i++)
+	{
+	unsigned long numTerms;
+        int idx = i+1;
+	int ii;
+
+	total_rows++;
+
+	if((numTerms = adb_load_alias_def(GLOBALS->adb, idx, GLOBALS->adb_terms)))
+		{
+		if(GLOBALS->adb_terms[0].first > GLOBALS->adb_terms[0].last)
+			{
+			GLOBALS->ae2_fr[match_idx].length = GLOBALS->adb_terms[0].first - GLOBALS->adb_terms[0].last + 1;
+			}
+			else
+			{
+			GLOBALS->ae2_fr[match_idx].length = GLOBALS->adb_terms[0].last - GLOBALS->adb_terms[0].first + 1;
+			}
+
+		GLOBALS->adb_idx_first[i] = GLOBALS->adb_terms[0].first;
+		GLOBALS->adb_idx_last[i] = GLOBALS->adb_terms[0].last;
+
+	        GLOBALS->ae2_fr[match_idx].s = idx + GLOBALS->ae2_num_facs; /* bias aliases after regular facs */
+
+		GLOBALS->ae2_fr[match_idx].facname = NULL;
+		GLOBALS->ae2_fr[match_idx].row = 0;
+	        GLOBALS->ae2_fr[match_idx].row_high = 0;
+	        GLOBALS->ae2_fr[match_idx].offset = 0;
+
+		GLOBALS->adb_num_terms[i] = numTerms;
+		GLOBALS->adb_aliases[i] = adb_alloc_2(numTerms * sizeof(ADB_TERM));
+
+		for(ii=0;ii<(numTerms);ii++)
+			{
+			GLOBALS->adb_aliases[i][ii].id = GLOBALS->adb_terms[ii+1].id;
+			GLOBALS->adb_aliases[i][ii].first = GLOBALS->adb_terms[ii+1].first;
+			GLOBALS->adb_aliases[i][ii].last = GLOBALS->adb_terms[ii+1].last;
+        		}
+		}
+		else
+		{
+		memcpy(&GLOBALS->ae2_fr[match_idx], &GLOBALS->ae2_fr[GLOBALS->adb_terms[0].id-1], sizeof(AE2_FACREF));
+
+		GLOBALS->adb_idx_first[i] = 0;
+		GLOBALS->adb_idx_last[i] = GLOBALS->ae2_fr[match_idx].length - 1;
+		}
+
+	match_idx++;
+	}
+#endif
+
 monolithic_node = calloc_2(total_rows, sizeof(struct Node));
 monolithic_sym = calloc_2(match_idx, sizeof(struct symbol));
 
@@ -470,47 +576,56 @@ match_idx = 0;
 for(i=0;i<GLOBALS->numfacs;i++)
         {
 	char *str;	
-        char buf[AE2_MAX_NAME_LENGTH+1];
-        int idx = i+1;
+        int idx;
 	unsigned long len, clen;
 	int row_iter, mx_row, mx_row_adjusted;
 
-	if((GLOBALS->ae2_regex_matches)&&(!aet2_rd_get_fac_process_mask(i))) continue;
-
-	len = ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
+#ifdef AET2_ALIASDB_IS_PRESENT
+	if(i < GLOBALS->ae2_num_facs)
+#endif
+		{
+		idx = i+1;
+		len = ae2_read_symbol_name(GLOBALS->ae2, idx, buf);
+		}
+#ifdef AET2_ALIASDB_IS_PRESENT
+		else
+		{
+		idx = i - GLOBALS->ae2_num_facs + 1;
+		len = adb_alias_name(GLOBALS->adb, idx, buf) - 1; /* it counts the null character */
+		}
+#endif
 
 	if(GLOBALS->ae2_fr[match_idx].length>1)
 		{
 		int len2;
-		FACREF info_fr;
-		unsigned long find_rc;
 
-		if((GLOBALS->ae2_info)&&((find_rc = ae2_read_find_symbol(GLOBALS->ae2_info, buf, &info_fr)))&&(info_fr.length == 32))
+#ifdef AET2_ALIASDB_IS_PRESENT
+		if(i < GLOBALS->ae2_num_facs)
+#endif
 			{
-			int bit;
-			char valstr[33];
-			unsigned int val = 0;
-			ae2_read_value(GLOBALS->ae2_info, &info_fr, 0, valstr);
-
-			for(bit=0;bit<32;bit++)
-				{
-				val <<= 1;
-				val |= (valstr[bit]&1);
-				}
-
-			len2 = sprintf(buf+len, "[%d:%d]", (val >> 16) & 0xffff, val & 0xffff);
+			len2 = sprintf_2_1d(buf+len, GLOBALS->ae2_fr[match_idx].length-1);
 			}
+#ifdef AET2_ALIASDB_IS_PRESENT
 			else
 			{
-			len2 = sprintf(buf+len, "[%d:%d]", 0, GLOBALS->ae2_fr[match_idx].length-1);
+			len2 = sprintf_2_2d(buf+len, GLOBALS->adb_idx_first[i - GLOBALS->ae2_num_facs], GLOBALS->adb_idx_last[i - GLOBALS->ae2_num_facs]);
 			}
+#endif
 
+		clen = (len + len2 + 1);
+                if(!GLOBALS->do_hier_compress)
+                        {
+			str=malloc_2(clen);
+                        }
+                        else
+                        {
+                        str = buf;
+                        }
 
-		str=malloc_2(clen = (len + len2 + 1));
 		if(clen > GLOBALS->longestname) GLOBALS->longestname = clen;
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, buf);
+			if(!GLOBALS->do_hier_compress) strcpy(str, buf);
 			}
 			else
 			{
@@ -521,11 +636,20 @@ for(i=0;i<GLOBALS->numfacs;i++)
 		}
 		else
 		{
-		str=malloc_2(clen = (len+1));
+		clen = (len+1);
+                if(!GLOBALS->do_hier_compress)
+                        {
+			str=malloc_2(clen);
+                        }
+                        else
+                        {
+                        str = buf;
+                        }
+
 		if(clen > GLOBALS->longestname) GLOBALS->longestname = clen;
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, buf);
+			if(!GLOBALS->do_hier_compress) strcpy(str, buf);
 			}
 			else
 			{
@@ -535,28 +659,41 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	        symadd_name_exists_sym_exists(s, str,0);
 		}
 		
-#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
-        GLOBALS->ae2_invert_idx[idx] = s;
-#endif
-
         mx_row = (GLOBALS->ae2_fr[match_idx].row < 1) ? 1 : GLOBALS->ae2_fr[match_idx].row;
 	mx_row_adjusted = (mx_row < 2) ? 0 : mx_row;
         n=&monolithic_node[mono_row_offset];
 	s->n = n;
 	mono_row_offset += mx_row;
 
+        if(GLOBALS->do_hier_compress)
+                {
+                s->name = compress_facility((unsigned char *)str, clen - 1);
+                }
+
 	for(row_iter = 0; row_iter < mx_row; row_iter++)
 		{
 	        n[row_iter].nname=s->name;
 	        n[row_iter].mv.mvlfac = (struct fac *)(GLOBALS->ae2_fr+match_idx); /* to keep from having to allocate duplicate mvlfac struct */
-							               /* use the info in the FACREF array instead                */
+							               /* use the info in the AE2_FACREF array instead                */
 		n[row_iter].array_height = mx_row_adjusted;
 		n[row_iter].this_row = row_iter;
 
 		if(GLOBALS->ae2_fr[match_idx].length>1)
 			{
-			n[row_iter].msi = 0;
-			n[row_iter].lsi = GLOBALS->ae2_fr[match_idx].length-1;
+#ifdef AET2_ALIASDB_IS_PRESENT
+			if(i < GLOBALS->ae2_num_facs)
+#endif
+				{
+				n[row_iter].msi = 0;
+				n[row_iter].lsi = GLOBALS->ae2_fr[match_idx].length-1;
+				}
+#ifdef AET2_ALIASDB_IS_PRESENT
+				else
+				{
+				n[row_iter].msi = GLOBALS->adb_idx_first[i - GLOBALS->ae2_num_facs];
+				n[row_iter].lsi = GLOBALS->adb_idx_last[i - GLOBALS->ae2_num_facs];
+				}
+#endif
 			n[row_iter].extvals = 1;
 			}
                  
@@ -567,13 +704,12 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	match_idx++;
         }
 
-if(GLOBALS->ae2_regex_matches)
-	{
-	free_2(GLOBALS->ae2_process_mask);
-	GLOBALS->numfacs = GLOBALS->ae2_regex_matches;
-	GLOBALS->ae2_regex_matches = 0;
-	GLOBALS->ae2_process_mask = calloc_2(1, GLOBALS->numfacs/8+1);
-	}
+#ifdef AET2_ALIASDB_IS_PRESENT
+if(GLOBALS->adb_idx_last) { free_2(GLOBALS->adb_idx_last); GLOBALS->adb_idx_last = NULL; }
+if(GLOBALS->adb_idx_first) { free_2(GLOBALS->adb_idx_first); GLOBALS->adb_idx_first = NULL; }
+#endif
+
+freeze_facility_pack();
 
 /* SPLASH */                            splash_sync(2, 5);
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
@@ -592,7 +728,9 @@ if(GLOBALS->fast_tree_sort)
 
 	for(i=0;i<GLOBALS->numfacs;i++)	
 		{
-		build_tree_from_name(GLOBALS->facs[i]->name, i);
+		int was_packed = HIER_DEPACK_STATIC; /* no need to free_2() afterward then */
+		char *sb = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
+		build_tree_from_name(sb, i);
 		}
 
 /* SPLASH */                            splash_sync(4, 5);
@@ -657,7 +795,7 @@ if(GLOBALS->fast_tree_sort)
 	}
 
 
-if(GLOBALS->ae2_time_xlate)
+if(GLOBALS->ae2_time_xlate) /* GLOBALS->ae2_time_xlate is currently unused, but could be again in the future */
 	{
 	GLOBALS->min_time = GLOBALS->ae2_time_xlate[0];
 	GLOBALS->max_time = GLOBALS->ae2_time_xlate[last_cycle - first_cycle];
@@ -696,7 +834,7 @@ if(skip_start || skip_end)
 	GLOBALS->min_time = b_start;
 	GLOBALS->max_time = b_end;
 
-	if(GLOBALS->ae2_time_xlate)
+	if(GLOBALS->ae2_time_xlate) /* GLOBALS->ae2_time_xlate is currently unused, but could be again in the future */
 		{
 		for(lim_idx = first_cycle; lim_idx <= last_cycle; lim_idx++)
 			{
@@ -734,7 +872,7 @@ static void ae2_callback(uint64_t *tim, unsigned int *facidx, char **value, unsi
 {
 struct HistEnt *htemp = histent_calloc();
 struct lx2_entry *l2e = &GLOBALS->ae2_lx2_table[*facidx][row];
-FACREF *f = GLOBALS->ae2_fr+(*facidx);
+AE2_FACREF *f = GLOBALS->ae2_fr+(*facidx);
 
 static int busycnt = 0;
 
@@ -796,17 +934,13 @@ struct ae2_ncycle_autosort *deadlist=NULL;
 struct ae2_ncycle_autosort *autofacs=NULL;
 char buf[AE2_MAXFACLEN+1];
 
-
-GLOBALS->ae2_msg_suppress = 1;
-GLOBALS->ae2_did_twirl = 0;
-
 autofacs = calloc_2(GLOBALS->numfacs, sizeof(struct ae2_ncycle_autosort));
 
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
 	if(aet2_rd_get_fac_process_mask(i))
 		{
-		int nr = ae2_read_symbol_rows(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+		int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 		if(!nr) nr = 1;
 		for(r=0;r<nr;r++)
 			{
@@ -820,7 +954,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 for(j=0;j<GLOBALS->ae2_num_sections;j++)
 	{
 	struct ae2_ncycle_autosort **autosort = NULL;
-	uint64_t *ith_range = ae2_read_ith_section_range(GLOBALS->ae2, j);
+	const uint64_t *ith_range = ae2_read_ith_section_range(GLOBALS->ae2, j);
 
 	cyc = *ith_range;
 	ecyc = *(ith_range+1);
@@ -836,13 +970,13 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 		{
 		if(aet2_rd_get_fac_process_mask(i))
 			{
-			int nr = ae2_read_symbol_rows(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+			int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 
 			if(nr<2)
 				{
 				nptr np = GLOBALS->ae2_lx2_table[i][0].np;
 	
-				ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+				ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 				if(strcmp(np->mv.value, buf))
 					{
 					strcpy(np->mv.value, buf);
@@ -865,7 +999,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			                                GLOBALS->ae2_fr[i].row = row;
 	
 							np = GLOBALS->ae2_lx2_table[i][row].np;
-			                                ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+			                                ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 							if(strcmp(np->mv.value, buf))
 								{
 								strcpy(np->mv.value, buf);
@@ -876,7 +1010,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 					}
 					else
 					{
-					int rows = ae2_read_symbol_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+					int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 					if(rows)
 						{
 			                        for(r=0;r<rows;r++)
@@ -887,7 +1021,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			                                GLOBALS->ae2_fr[i].row = row;
 	
 							np = GLOBALS->ae2_lx2_table[i][row].np;
-			                                ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+			                                ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 							if(strcmp(np->mv.value, buf))
 								{
 								strcpy(np->mv.value, buf);
@@ -910,11 +1044,11 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 		if(!aet2_rd_get_fac_process_mask(i)) continue;
 
-		nr = ae2_read_symbol_rows(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+		nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 		if(nr < 2)
 			{
 			np = GLOBALS->ae2_lx2_table[i][0].np;
-			ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, np->mv.value);
+			ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, np->mv.value);
 			}
 			else
 			{
@@ -931,7 +1065,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 	                                GLOBALS->ae2_fr[i].row = row;
 					/* np = GLOBALS->ae2_lx2_table[i][row].np; */
-					ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+					ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 	
 					if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 					}
@@ -947,7 +1081,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				}
 				else
 				{
-				int rows = ae2_read_symbol_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+				int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 				uint64_t mxcyc = end_cycle+1;
 
 	                        for(r=0;r<rows;r++)
@@ -957,7 +1091,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 	                                GLOBALS->ae2_fr[i].row = row;
 					/* np = GLOBALS->ae2_lx2_table[i][row].np; */
-					ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+					ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
 	
 					if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 					}
@@ -1006,7 +1140,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				int nr;	
 	
 				i = t-autofacs;
-				nr = ae2_read_symbol_rows(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+				nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 
 				if(nr<2)
 					{
@@ -1014,7 +1148,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 
 					ae2_callback(&step_cyc, &i, &np->mv.value, 0);
 		
-					ncyc = ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, np->mv.value);
+					ncyc = ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, np->mv.value);
 					}
 					else
 					{
@@ -1032,14 +1166,14 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			                                GLOBALS->ae2_fr[i].row = row;
 							npr = GLOBALS->ae2_lx2_table[i][row].np;
 
-							ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
 							if(strcmp(buf, npr->mv.value))
 								{
 								strcpy(npr->mv.value, buf);
 								ae2_callback(&step_cyc, &i, &npr->mv.value, row);
 								}
 
-							ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
 							if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 							}
 	
@@ -1054,7 +1188,7 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 						}
 						else
 						{
-						int rows = ae2_read_symbol_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+						int rows = ae2_read_symbol_rows_2(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
 						uint64_t mxcyc = end_cycle+1;
 
 			                        for(r=0;r<rows;r++)
@@ -1065,14 +1199,14 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			                                GLOBALS->ae2_fr[i].row = row;
 							npr = GLOBALS->ae2_lx2_table[i][row].np;
 
-							ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							ae2_read_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
 							if(strcmp(buf, npr->mv.value))
 								{
 								strcpy(npr->mv.value, buf);
 								ae2_callback(&step_cyc, &i, &npr->mv.value, row);
 								}
 
-							ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							ncyc =	ae2_read_next_value_2(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
 							if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
 							}
 	
@@ -1114,7 +1248,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	{
 	if(aet2_rd_get_fac_process_mask(i))
 		{
-		int nr = ae2_read_symbol_rows(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
+		int nr = ae2_read_symbol_rows_2(GLOBALS->ae2,GLOBALS->ae2_fr[i].s);
 		if(!nr) nr = 1;
 		for(r=0;r<nr;r++)
 			{
@@ -1126,13 +1260,6 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	}
 
 free_2(autofacs);
-
-GLOBALS->ae2_msg_suppress = 0;
-if(GLOBALS->ae2_did_twirl)
-	{
-	fprintf(stderr,"\n");
-	GLOBALS->ae2_did_twirl = 0;
-	}
 return(0);
 }
 
@@ -1144,21 +1271,24 @@ void import_ae2_trace(nptr np)
 {
 struct HistEnt *htemp, *histent_tail;
 int len, i;
-FACREF *f;
+AE2_FACREF *f;
 int txidx;
 int r, nr;
 
-if(!(f=(FACREF *)(np->mv.mvlfac))) return;	/* already imported */
+if(!(f=(AE2_FACREF *)(np->mv.mvlfac))) return;	/* already imported */
 
 txidx = f - GLOBALS->ae2_fr;
-nr = ae2_read_symbol_rows(GLOBALS->ae2, f->s);
+nr = ae2_read_symbol_rows_2(GLOBALS->ae2, f->s);
 
 /* new stuff */
 len = f->length;
 
 if((1)||(f->row <= 1)) /* sorry, arrays not supported yet in the viewer */
 	{
-	fprintf(stderr, "Import: %s\n", np->nname);
+	int flagged = HIER_DEPACK_STATIC;
+	char *str = hier_decompress_flagged(np->nname, &flagged);
+	fprintf(stderr, "Import: %s\n", str);
+
 	if(nr<1) nr=1;
 	if(!GLOBALS->ae2_lx2_table[txidx])
 		{
@@ -1175,6 +1305,11 @@ if((1)||(f->row <= 1)) /* sorry, arrays not supported yet in the viewer */
 	}
 	else
 	{
+	int flagged = HIER_DEPACK_STATIC;
+	char *str = hier_decompress_flagged(np->nname, &flagged);
+
+	fprintf(stderr, AET2_RDLOAD"Skipping array: %s (%d rows)\n", str, f->row);
+
 	if(nr<1) nr=1;
 	if(!GLOBALS->ae2_lx2_table[txidx])
 		{
@@ -1184,8 +1319,6 @@ if((1)||(f->row <= 1)) /* sorry, arrays not supported yet in the viewer */
 	                GLOBALS->ae2_lx2_table[txidx][r].np = &np[r];
 	                }
 		}
-
-	fprintf(stderr, AET2_RDLOAD"Skipping array: %s (%d rows)\n", np->nname, f->row);
 	}
 
 
@@ -1264,11 +1397,11 @@ for(r = 0; r < nr; r++)
  */
 void ae2_set_fac_process_mask(nptr np)
 {
-FACREF *f;
+AE2_FACREF *f;
 int txidx;
 int r, nr;
 
-if(!(f=(FACREF *)(np->mv.mvlfac))) return;	/* already imported */
+if(!(f=(AE2_FACREF *)(np->mv.mvlfac))) return;	/* already imported */
 
 txidx = f - GLOBALS->ae2_fr;
 
@@ -1314,8 +1447,8 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 	if(aet2_rd_get_fac_process_mask(txidx))
 		{
 		struct HistEnt *htemp, *histent_tail;
-		FACREF *f = GLOBALS->ae2_fr+txidx;
-		int r, nr = ae2_read_symbol_rows(GLOBALS->ae2, f->s);
+		AE2_FACREF *f = GLOBALS->ae2_fr+txidx;
+		int r, nr = ae2_read_symbol_rows_2(GLOBALS->ae2, f->s);
 		int len = f->length;
 
 		if(nr<1) nr=1;
@@ -1396,157 +1529,6 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 	}
 }
 
-
-#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
-struct symbol *symfind_ae2(char *s, unsigned int *rows_return)
-{
-char *s2 = s;
-char buf[AE2_MAX_NAME_LENGTH+1];
-char *d = buf;
-char *last_brack = NULL;
-char *last_brace = NULL;
-struct facref fr;
-ulong u;
-
-if ((!s)||(!s[0])) return(NULL);
-if(rows_return)
-        {
-        *rows_return = 0;
-        }
-
-while(*s2)
-	{
-	*d = *s2;
-
-	if(*s2 == '[')
-		{
-		last_brack = d;
-		}
-	else if(*s2 == '{')
-		{
-		last_brace = d;
-		}
-
-	s2++;
-	d++;
-	}
-*d = 0;
-
-d = buf;
-if(last_brack)
-	{
-	*last_brack = 0;
-	}
-
-if(rows_return)
-	{
-	if(last_brace)
-		{
-		*rows_return = atoi(last_brace+1);
-		}
-		else
-		{
-		*rows_return = 0;
-		}
-	}
-
-u = ae2_read_find_symbol(GLOBALS->ae2, d, &fr);
-
-return(GLOBALS->ae2_invert_idx[u]);
-}
-#endif
-
 #endif
 /* ...of AET2_IS_PRESENT */
 
-/*
- * $Id: ae2.c,v 1.19 2010/09/16 15:24:25 gtkwave Exp $
- * $Log: ae2.c,v $
- * Revision 1.19  2010/09/16 15:24:25  gtkwave
- * non-sparse array fix
- *
- * Revision 1.18  2010/09/16 05:05:16  gtkwave
- * dummy up sparse vs regular array handling
- *
- * Revision 1.17  2010/09/16 04:40:25  gtkwave
- * disable arrays for now to track down sparse vs regular array crashes
- *
- * Revision 1.16  2010/05/27 06:56:39  gtkwave
- * printf warning fixes
- *
- * Revision 1.15  2010/03/19 17:07:22  gtkwave
- * added missing ->symbol after structure type changed
- *
- * Revision 1.14  2010/03/15 15:57:28  gtkwave
- * only allocate hash when necessary
- *
- * Revision 1.13  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.12  2010/03/13 19:48:53  gtkwave
- * remove nextinaet field and replace with temp symchain
- *
- * Revision 1.11  2010/01/23 03:21:11  gtkwave
- * hierarchy fixes when characters < "." are in the signal names
- *
- * Revision 1.10  2009/07/01 07:39:12  gtkwave
- * decorating hierarchy tree with module type info
- *
- * Revision 1.9  2008/12/25 03:21:57  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.8  2008/09/27 19:08:39  gtkwave
- * compiler warning fixes
- *
- * Revision 1.7  2008/06/17 18:03:45  gtkwave
- * added time = -1 endcaps
- *
- * Revision 1.6  2008/02/19 22:00:28  gtkwave
- * added aetinfo support
- *
- * Revision 1.5  2007/08/31 22:42:43  gtkwave
- * 3.1.0 RC3 updates
- *
- * Revision 1.4  2007/08/26 21:35:39  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.6  2007/08/23 23:28:48  gtkwave
- * reload fail handling and retries
- *
- * Revision 1.1.1.1.2.5  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.4  2007/08/07 03:18:54  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.3  2007/08/06 03:50:45  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.2  2007/08/05 02:27:18  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.1  2007/07/28 19:50:39  kermin
- * Merged in the main line
- *
- * Revision 1.3  2007/06/23 02:58:26  gtkwave
- * added bounds checking on start vs end cycle so they don't invert
- *
- * Revision 1.2  2007/06/23 02:37:27  gtkwave
- * static section size is now dynamic
- *
- * Revision 1.1.1.1  2007/05/30 04:27:40  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:05  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 01:39:00  gtkwave
- * initial release
- *
- */
