@@ -472,14 +472,14 @@ int AddNodeTraceReturn(nptr nd, char *aliasname, Trptr *tret)
     {
       if(!GLOBALS->hier_max_level) 
 	{
-	  int flagged = 0;
+	  int flagged = HIER_DEPACK_ALLOC;
 
 	  t->name = hier_decompress_flagged(nd->nname, &flagged);
 	  t->is_depacked = (flagged != 0);
 	}
       else
 	{
-	  int flagged = 0;
+	  int flagged = HIER_DEPACK_ALLOC;
 	  char *tbuff = hier_decompress_flagged(nd->nname, &flagged);
 	  if(!flagged)
 	    {
@@ -1525,127 +1525,3 @@ if((underflow_sticky) || (oc_cnt > 0))
 	}
 }
 
-/*
- * $Id: analyzer.c,v 1.32 2011/01/13 17:20:39 gtkwave Exp $
- * $Log: analyzer.c,v $
- * Revision 1.32  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.31  2010/09/10 05:58:40  gtkwave
- * structor reordering of VectorEnt to benefit 32-bit architectures
- *
- * Revision 1.30  2010/08/02 20:44:35  gtkwave
- * added gtkwave::cbTracesUpdated
- *
- * Revision 1.29  2010/07/06 16:06:09  gtkwave
- * defensive re-link fix in PasteBuffer
- *
- * Revision 1.28  2010/07/01 17:58:23  gtkwave
- * Segmentation fault on signal reordering - ID: 3023401
- *
- * Revision 1.27  2010/06/23 05:45:34  gtkwave
- * warnings fixes
- *
- * Revision 1.26  2010/04/15 00:30:23  gtkwave
- * don't propagate ttranslate filter into groups
- *
- * Revision 1.25  2010/04/13 18:11:42  gtkwave
- * propagate trace highlighting into transactions
- *
- * Revision 1.24  2010/04/07 01:50:45  gtkwave
- * improved name handling for bvname, add $next transaction operation
- *
- * Revision 1.23  2010/04/06 06:19:06  gtkwave
- * deallocate transaction trace name
- *
- * Revision 1.22  2010/04/04 19:09:57  gtkwave
- * rename name->bvname in struct BitVector for easier grep tracking
- *
- * Revision 1.21  2010/04/04 07:12:40  gtkwave
- * deallocate transaction cache on FreeTrace
- *
- * Revision 1.20  2010/03/31 16:32:20  gtkwave
- * stale marker fix for ttranslate on save file loads before GUI initialized
- *
- * Revision 1.19  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.18  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.17  2010/02/28 21:59:50  gtkwave
- * defensive relinking of t_prev in cut and paste buffers
- *
- * Revision 1.16  2010/02/26 18:19:00  gtkwave
- * defensive re-link of t_prev
- *
- * Revision 1.15  2010/01/23 03:21:11  gtkwave
- * hierarchy fixes when characters < "." are in the signal names
- *
- * Revision 1.14  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.13  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.12  2009/11/05 23:11:09  gtkwave
- * added EnsureGroupsMatch()
- *
- * Revision 1.11  2009/11/03 07:08:21  gtkwave
- * enabled reverse when groups present
- *
- * Revision 1.10  2009/11/02 22:43:43  gtkwave
- * enable sorting on groups (need to do reverse yet)
- *
- * Revision 1.9  2009/11/02 05:45:14  gtkwave
- * temporarily disable sort when groups present
- *
- * Revision 1.8  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.7  2008/12/18 01:31:29  gtkwave
- * integrated experimental autoscroll code on signal adds
- *
- * Revision 1.6  2008/08/05 17:49:39  gtkwave
- * comment trace dnd fix
- *
- * Revision 1.5  2008/07/18 17:27:00  gtkwave
- * adding hierpack code
- *
- * Revision 1.4  2008/06/11 08:01:40  gtkwave
- * gcc 4.3.x compiler warning fixes
- *
- * Revision 1.3  2008/01/02 18:17:26  gtkwave
- * added standard click semantics with user_standard_clicking rc variable
- *
- * Revision 1.2  2007/08/26 21:35:39  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.4  2007/08/25 19:43:45  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.3  2007/08/07 03:18:54  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.2  2007/08/06 03:50:45  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.1  2007/08/05 02:27:18  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1  2007/05/30 04:27:20  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:05  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:11  gtkwave
- * initial release
- *
- */
-
