@@ -220,7 +220,7 @@ for(;;)
 			if(!strncmp("minimum xtag       : (", rc, 22))
 				{
 				unsigned int lo = 0, hi = 0;
-				sscanf(rc + 22, "%d %d", &hi, &lo);
+				sscanf(rc + 22, "%u %u", &hi, &lo);
 				GLOBALS->min_time = (TimeType)((((UTimeType)hi)<<32) + ((UTimeType)lo));
 
 				msk |= 2;
@@ -229,7 +229,7 @@ for(;;)
 			if(!strncmp("maximum xtag       : (", rc, 22))
 				{
 				unsigned int lo = 0, hi = 0;
-				sscanf(rc + 22, "%d %d", &hi, &lo);
+				sscanf(rc + 22, "%u %u", &hi, &lo);
 				GLOBALS->max_time = (TimeType)((((UTimeType)hi)<<32) + ((UTimeType)lo));
 
 				msk |= 4;
@@ -348,7 +348,7 @@ for(;;)
 				unsigned int l, r;
 				char s1[32], s3[32], s4[32];
 				unsigned int d2;
-				sscanf(last_l, "l:%d r:%d %s %d %s %s", &l, &r, s1, &d2, s3, s4);
+				sscanf(last_l, "l:%u r:%u %s %u %s %s", &l, &r, s1, &d2, s3, s4);
 
 				GLOBALS->extload_idcodes[i] = d2;
 				if(GLOBALS->extload_inv_idcodes[d2] == 0) GLOBALS->extload_inv_idcodes[d2] = i+1; /* root alias */
@@ -826,7 +826,7 @@ if(last_modification_check()) /* place array height check here in an "&&" branch
 			if(rc)
 				{
 				unsigned int lo = 0, hi = 0;
-				sscanf(rc+1, "%d %d", &hi, &lo);
+				sscanf(rc+1, "%u %u", &hi, &lo);
 				tim = (TimeType)((((UTimeType)hi)<<32) + ((UTimeType)lo));
 				
 				rc = strchr(rc+1, ')');
@@ -954,47 +954,3 @@ if(nold!=np)
 
 #endif
 
-/*
- * $Id: extload.c,v 1.13 2011/01/13 17:20:39 gtkwave Exp $
- * $Log: extload.c,v $
- * Revision 1.13  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.12  2011/01/07 20:17:10  gtkwave
- * remove redundant fields from struct fac
- *
- * Revision 1.11  2010/05/27 06:56:39  gtkwave
- * printf warning fixes
- *
- * Revision 1.10  2010/03/19 17:50:57  gtkwave
- * compatibility fixes from fac struct changes
- *
- * Revision 1.9  2010/03/13 21:38:16  gtkwave
- * fixed && used in logical operations for allocating ExtNode
- *
- * Revision 1.8  2010/03/13 19:16:00  gtkwave
- * removal of useless symbol->nextinaet code
- *
- * Revision 1.7  2010/03/01 05:16:26  gtkwave
- * move compressed hier tree traversal to hierpack
- *
- * Revision 1.6  2010/01/23 03:21:11  gtkwave
- * hierarchy fixes when characters < "." are in the signal names
- *
- * Revision 1.5  2009/07/01 07:39:12  gtkwave
- * decorating hierarchy tree with module type info
- *
- * Revision 1.4  2009/02/16 17:16:05  gtkwave
- * extload error hardening and recovery
- *
- * Revision 1.3  2009/01/28 20:36:56  gtkwave
- * convert 3 value to z in value changes, likewise 2 to x
- *
- * Revision 1.2  2009/01/27 07:34:42  gtkwave
- * use atoi rather than atoi64
- *
- * Revision 1.1  2009/01/27 07:04:28  gtkwave
- * added extload external process loader capability
- *
- *
- */
