@@ -732,6 +732,7 @@ free_2(f_name_len); f_name_len = NULL;
 
 if(numvars != GLOBALS->numfacs) { GLOBALS->mvlfacs_fst_rvs_alias = realloc_2(GLOBALS->mvlfacs_fst_rvs_alias, numvars * sizeof(fstHandle)); }
 
+decorated_module_cleanup(); /* ...also now in gtk2_treesearch.c */
 freeze_facility_pack();
 iter_through_comp_name_table();
 
@@ -1142,7 +1143,13 @@ if(np->mv.mvlfac->flags&VZT_RD_SYM_F_ALIAS)
 		}
 	}
 
-fprintf(stderr, "Import: %s\n", np->nname);
+
+{
+int flagged = HIER_DEPACK_STATIC;
+char *str = hier_decompress_flagged(np->nname, &flagged);
+fprintf(stderr, "Import: %s\n", str);
+}
+
 
 /* new stuff */
 len = np->mv.mvlfac->len;
@@ -1435,161 +1442,3 @@ for(txidxi=0;txidxi<GLOBALS->fst_maxhandle;txidxi++)
 	}
 }
 
-/*
- * $Id: fst.c,v 1.51 2011/01/22 05:42:52 gtkwave Exp $
- * $Log: fst.c,v $
- * Revision 1.51  2011/01/22 05:42:52  gtkwave
- * replace some string copies with mem copies
- *
- * Revision 1.50  2011/01/22 01:29:24  gtkwave
- * sourcecode cleanup / warnings fixes
- *
- * Revision 1.49  2011/01/21 22:40:28  gtkwave
- * pass string lengths from api directly to code to avoid length calculations
- *
- * Revision 1.48  2011/01/21 21:32:30  gtkwave
- * remove redundant and repetitive allocations
- *
- * Revision 1.47  2011/01/21 21:04:31  gtkwave
- * signal name processing optimization on reader
- *
- * Revision 1.46  2011/01/20 23:34:53  gtkwave
- * fix to autocoalesce code
- *
- * Revision 1.45  2011/01/20 19:07:20  gtkwave
- * add reverse equality mem compare
- *
- * Revision 1.44  2011/01/20 05:35:56  gtkwave
- * fast tree sort = 0 fix
- *
- * Revision 1.43  2011/01/20 02:16:13  gtkwave
- * remove redundant strlen ops and replace with query function
- *
- * Revision 1.42  2011/01/19 06:36:31  gtkwave
- * added tree allocation pool when misaligned structs are enabled
- *
- * Revision 1.41  2011/01/18 00:00:12  gtkwave
- * preliminary tree component support
- *
- * Revision 1.40  2011/01/17 19:24:21  gtkwave
- * tree modifications to support decorated internal hierarchy nodes
- *
- * Revision 1.39  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.38  2011/01/07 20:17:10  gtkwave
- * remove redundant fields from struct fac
- *
- * Revision 1.37  2010/12/19 07:59:10  gtkwave
- * warnings fixes
- *
- * Revision 1.36  2010/12/10 20:13:13  gtkwave
- * added escape codes to string record parsing
- *
- * Revision 1.35  2010/12/09 19:02:29  gtkwave
- * back out commented out string flag setting
- *
- * Revision 1.34  2010/12/09 15:19:16  gtkwave
- * preliminary support for variable-length string datatype in FST
- *
- * Revision 1.33  2010/10/02 18:58:55  gtkwave
- * ctype.h compiler warning fixes (char vs int)
- *
- * Revision 1.32  2010/09/16 19:40:08  gtkwave
- * back out hierarchy removal
- *
- * Revision 1.31  2010/09/16 19:23:37  gtkwave
- * duplicate tree fix for when compressed facilities are being used
- *
- * Revision 1.30  2010/09/15 18:35:42  gtkwave
- * added F_NAME_MODULUS to reduce temp memory usage
- *
- * Revision 1.29  2010/09/14 21:51:39  gtkwave
- * fixed dangling fnam alloc
- *
- * Revision 1.28  2010/06/02 03:51:30  gtkwave
- * don't autocoalesce escape identifiers
- *
- * Revision 1.27  2010/06/02 03:23:04  gtkwave
- * disable autocoalesce if Icarus Verilog is detected
- *
- * Revision 1.26  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.25  2010/03/13 21:38:16  gtkwave
- * fixed && used in logical operations for allocating ExtNode
- *
- * Revision 1.24  2010/03/13 19:16:00  gtkwave
- * removal of useless symbol->nextinaet code
- *
- * Revision 1.23  2010/03/12 16:11:49  gtkwave
- * added missing hierarchy boundary sort
- *
- * Revision 1.22  2010/03/11 23:31:52  gtkwave
- * remove name field from struct fac
- *
- * Revision 1.21  2010/03/01 05:16:26  gtkwave
- * move compressed hier tree traversal to hierpack
- *
- * Revision 1.20  2010/02/22 21:13:36  gtkwave
- * added "realtime" VCD variable
- *
- * Revision 1.19  2009/08/06 20:03:31  gtkwave
- * warnings fixes
- *
- * Revision 1.18  2009/07/26 20:18:43  gtkwave
- * fix "x" value for time -1 on reals to be "NaN"
- *
- * Revision 1.17  2009/07/12 21:01:03  gtkwave
- * elide duplicate consecutive values for histents
- *
- * Revision 1.16  2009/07/07 20:12:53  gtkwave
- * convert hex capitalization to match verilog
- *
- * Revision 1.15  2009/07/07 15:48:37  gtkwave
- * EVCD "f" value fix (should be z not x)
- *
- * Revision 1.14  2009/07/06 21:41:36  gtkwave
- * evcd support issues
- *
- * Revision 1.13  2009/07/03 18:48:33  gtkwave
- * fst read compatibility fixes for mingw
- *
- * Revision 1.12  2009/07/01 16:47:47  gtkwave
- * move decorated module alloc routine to tree.c
- *
- * Revision 1.11  2009/07/01 08:16:33  gtkwave
- * hardening of fst reader for cygwin multiple loading
- *
- * Revision 1.10  2009/07/01 07:39:12  gtkwave
- * decorating hierarchy tree with module type info
- *
- * Revision 1.9  2009/06/29 18:16:23  gtkwave
- * adding framework for module type annotation on inner tree nodes
- *
- * Revision 1.8  2009/06/27 23:10:32  gtkwave
- * added display of type info for variables in tree view
- *
- * Revision 1.7  2009/06/25 18:31:19  gtkwave
- * added event types for VCD+FST and impulse arrows on event types
- *
- * Revision 1.6  2009/06/24 21:54:53  gtkwave
- * added sign bits to bitfield parsing for vars
- *
- * Revision 1.5  2009/06/23 22:18:09  gtkwave
- * added slab allocator for doubles in FST traces
- *
- * Revision 1.4  2009/06/20 19:36:56  gtkwave
- * floating-point read optimizations in read iter blocks
- *
- * Revision 1.3  2009/06/08 03:51:46  gtkwave
- * added reverse mappings to facidx for interleaved normal + alias signal fix
- *
- * Revision 1.2  2009/06/07 19:39:41  gtkwave
- * move to one pass hier processing algorithm, add blackout region support
- *
- * Revision 1.1  2009/06/07 08:40:44  gtkwave
- * adding FST support
- *
- */
-
