@@ -68,27 +68,34 @@ static const struct Global globals_base_values =
 /*
  * ae2.c
  */
+#ifdef AET2_IS_PRESENT
+#ifdef AET2_ALIASDB_IS_PRESENT
+NULL, /* adb_alias_stream_file */
+0, /* adb */
+0, /* adb_max_terms */
+NULL, /* adb_terms */
+NULL, /* adb_aliases */
+NULL, /* adb_num_terms */
+NULL, /* adb_idx_first */
+NULL, /* adb_idx_last */
+NULL, /* adb_alloc_pool_base */
+0, /* adb_alloc_idx */
+#endif
+0, /* ae2_num_facs */
+0, /* ae2_num_aliases */
 0, /* ae2_num_sections */
 NULL, /* ae2_lx2_table */
 NULL, /* ae2_f */
 NULL, /* ae2 */
 NULL, /* ae2_fr */
-NULL, /* ae2_info_f */
-NULL, /* ae2_info */
-NULL, /* ae2_time_xlate */
-LLDescriptor(0), /* ae2_start_cyc */
-LLDescriptor(0), /* ae2_end_cyc */
 LLDescriptor(0), /* ae2_start_limit_cyc */
 LLDescriptor(0), /* ae2_end_limit_cyc */
 NULL, /* ae2_process_mask */
-0, /* ae2_msg_suppress */
-NULL, /* ae2_regex_head */
-0, /* ae2_regex_matches */
-0, /* ae2_twirl_pos */
-0, /* ae2_did_twirl */
-#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
-NULL, /* ae2_invert_idx */
 #endif
+LLDescriptor(0), /* ae2_start_cyc */
+LLDescriptor(0), /* ae2_end_cyc */
+NULL, /* ae2_time_xlate */
+0, /* disable_ae2_alias */
 
 
 /*
@@ -472,7 +479,6 @@ NULL, /* loaded_file_name */
 NULL, /* unoptimized_vcd_file_name  */
 NULL, /* skip_start */
 NULL, /* skip_end */
-NULL, /* indirect_fname */
 MISSING_FILE, /* loaded_file_type */
 0, /* is_optimized_stdin_vcd */
 NULL, /* whoami 190 */
@@ -895,6 +901,10 @@ NULL, /* clist_translate_c_4 442 */
 /*
  * tree.c
  */
+#ifdef _WAVE_HAVE_JUDY
+NULL, /* sym_tree */
+NULL, /* sym_tree_addresses */
+#endif
 NULL, /* treeroot 443 */
 NULL, /* mod_tree_parent */
 NULL, /* module_tree_c_1 444 */
@@ -1296,6 +1306,8 @@ NULL, /* gccache_dash_wavewindow_c_1 */
 0, /* str_wid_state */
 0, /* str_wid_slider */
 0, /* str_wid_height */
+0, /* ruler_origin */
+0, /* ruler_step */
 
 
 /*
@@ -1639,6 +1651,9 @@ void reload_into_new_context(void)
 #endif
  new_globals->use_pango_fonts = GLOBALS->use_pango_fonts;
 
+ new_globals->ruler_origin = GLOBALS->ruler_origin;
+ new_globals->ruler_step = GLOBALS->ruler_step;
+
  /* busy.c */
  new_globals->busycursor_busy_c_1 = GLOBALS->busycursor_busy_c_1;
  new_globals->busy_busy_c_1 = GLOBALS->busy_busy_c_1;
@@ -1763,6 +1778,8 @@ void reload_into_new_context(void)
  new_globals->vector_padding = GLOBALS->vector_padding;
  new_globals->zoombase = GLOBALS->zoombase;
 
+ new_globals->disable_ae2_alias = GLOBALS->disable_ae2_alias;
+
  new_globals->splash_disable = 1; /* to disable splash for reload */
  new_globals->strace_repeat_count = GLOBALS->strace_repeat_count; /* for edgebuttons and also strace */
 
@@ -1787,7 +1804,6 @@ void reload_into_new_context(void)
  /* lxt2.c / vzt.c / ae2.c */
  strcpy2_into_new_context(new_globals, &new_globals->skip_start, &GLOBALS->skip_start);
  strcpy2_into_new_context(new_globals, &new_globals->skip_end, &GLOBALS->skip_end);
- strcpy2_into_new_context(new_globals, &new_globals->indirect_fname, &GLOBALS->indirect_fname);
 
  /* main.c */
  new_globals->use_toolbutton_interface = GLOBALS->use_toolbutton_interface;
@@ -1882,8 +1898,11 @@ void reload_into_new_context(void)
    case FST_FILE: fstReaderClose(GLOBALS->fst_fst_c_1); GLOBALS->fst_fst_c_1 = NULL; break;
    case AE2_FILE: 
 #ifdef AET2_IS_PRESENT
+#ifdef AET2_ALIASDB_IS_PRESENT
+	if(GLOBALS->adb) { adb_close_db(GLOBALS->adb); GLOBALS->adb = 0; }
+	/* if(GLOBALS->m_alias_stream_file) { fclose(GLOBALS->m_alias_stream_file); GLOBALS->m_alias_stream_file = NULL; } */
 	ae2_read_end(GLOBALS->ae2); fclose(GLOBALS->ae2_f); 
-	if(GLOBALS->ae2_info) { ae2_read_end(GLOBALS->ae2_info); fclose(GLOBALS->ae2_info_f); } 
+#endif
 #endif
 	break;
   
@@ -2067,8 +2086,12 @@ void reload_into_new_context(void)
 			break;
 
    		case AE2_FILE: 
-			ae2_main(GLOBALS->loaded_file_name,GLOBALS->skip_start,GLOBALS->skip_end,GLOBALS->indirect_fname);
+#ifdef AET2_IS_PRESENT
+			ae2_main(GLOBALS->loaded_file_name,GLOBALS->skip_start,GLOBALS->skip_end);
 			load_was_success = (GLOBALS->ae2 != NULL);
+#else
+			load_was_success = 0; /* never executes as AE2_FILE won't be set */
+#endif
 			break;
 
    		case GHW_FILE: 
@@ -2499,7 +2522,11 @@ void free_and_destroy_page_context(void)
    case FST_FILE: fstReaderClose(GLOBALS->fst_fst_c_1); GLOBALS->fst_fst_c_1 = NULL; break;
    case AE2_FILE:
 #ifdef AET2_IS_PRESENT
+#ifdef AET2_ALIASDB_IS_PRESENT
+	if(GLOBALS->adb) { adb_close_db(GLOBALS->adb); GLOBALS->adb = 0; }
+	/* if(GLOBALS->adb_alias_stream_file) { fclose(GLOBALS->adb_alias_stream_file); GLOBALS->adb_alias_stream_file = NULL; } */
         ae2_read_end(GLOBALS->ae2); fclose(GLOBALS->ae2_f);
+#endif
 #endif
         break;
  
