@@ -69,27 +69,34 @@ struct Global{
 /*
  * ae2.c
  */
+#ifdef AET2_IS_PRESENT
+#ifdef AET2_ALIASDB_IS_PRESENT
+FILE *adb_alias_stream_file;
+ADB_DB adb;
+unsigned long adb_max_terms;
+ADB_TERM *adb_terms;
+ADB_TERM **adb_aliases;
+unsigned short *adb_num_terms;
+unsigned short *adb_idx_first;
+unsigned short *adb_idx_last;
+unsigned char *adb_alloc_pool_base;
+size_t adb_alloc_idx;
+#endif
+unsigned long ae2_num_facs;
+unsigned long ae2_num_aliases;
 unsigned long ae2_num_sections;
 struct lx2_entry **ae2_lx2_table;
 FILE *ae2_f;
 AE2_HANDLE *ae2;
-FACREF *ae2_fr;
-FILE *ae2_info_f;
-AE2_HANDLE *ae2_info;
-TimeType *ae2_time_xlate;
-TimeType ae2_start_cyc;
-TimeType ae2_end_cyc;
+AE2_FACREF *ae2_fr;
 TimeType ae2_start_limit_cyc;
 TimeType ae2_end_limit_cyc;
 char *ae2_process_mask;
-char ae2_msg_suppress;
-struct regex_links *ae2_regex_head;
-int ae2_regex_matches;
-int ae2_twirl_pos;
-int ae2_did_twirl;
-#ifdef AE2_EXPERIMENTAL_TO_INTEGRATE
-struct symbol **ae2_invert_idx;
 #endif
+TimeType ae2_start_cyc;
+TimeType ae2_end_cyc;
+TimeType *ae2_time_xlate;
+char disable_ae2_alias;
 
 
 /*
@@ -472,7 +479,6 @@ char *loaded_file_name;
 char *unoptimized_vcd_file_name;
 char *skip_start;
 char *skip_end;
-char *indirect_fname;
 enum FileType loaded_file_type;
 char is_optimized_stdin_vcd;
 char *whoami; /* from main.c 201 */
@@ -878,6 +884,10 @@ GtkWidget *clist_translate_c_4; /* from translate.c 472 */
 /*
  * tree.c
  */
+#ifdef _WAVE_HAVE_JUDY
+Pvoid_t sym_tree;
+Pvoid_t sym_tree_addresses;
+#endif
 struct tree *treeroot; /* from tree.c 473 */
 struct tree *mod_tree_parent; /* from tree.c */
 char *module_tree_c_1; /* from tree.c 474 */
@@ -1279,6 +1289,8 @@ int str_wid_bigw;
 int str_wid_state;
 int str_wid_slider;
 int str_wid_height;
+TimeType ruler_origin;
+TimeType ruler_step;
 
 
 /*
