@@ -385,13 +385,13 @@ GLOBALS->dict_24_offset_lxt_c_1 = get_32(GLOBALS->zdictionary_offset_lxt_c_1+12)
 GLOBALS->dict_32_offset_lxt_c_1 = get_32(GLOBALS->zdictionary_offset_lxt_c_1+16);
 GLOBALS->dict_width_lxt_c_1 = get_32(GLOBALS->zdictionary_offset_lxt_c_1+20);
 
-DEBUG(fprintf(stderr, LXTHDR"zdictionary_offset = %08x\n", zdictionary_offset));
+DEBUG(fprintf(stderr, LXTHDR"zdictionary_offset = %08x\n", GLOBALS->zdictionary_offset_lxt_c_1));
 DEBUG(fprintf(stderr, LXTHDR"zdictionary_predec_size = %08x\n\n", GLOBALS->zdictionary_predec_size_lxt_c_1));
-DEBUG(fprintf(stderr, LXTHDR"dict_num_entries = %d\n", dict_num_entries));
-DEBUG(fprintf(stderr, LXTHDR"dict_string_mem_required = %d\n", dict_string_mem_required));
-DEBUG(fprintf(stderr, LXTHDR"dict_16_offset = %d\n", dict_16_offset));
-DEBUG(fprintf(stderr, LXTHDR"dict_24_offset = %d\n", dict_24_offset));
-DEBUG(fprintf(stderr, LXTHDR"dict_32_offset = %d\n", dict_32_offset));
+DEBUG(fprintf(stderr, LXTHDR"dict_num_entries = %d\n", GLOBALS->dict_num_entries_lxt_c_1));
+DEBUG(fprintf(stderr, LXTHDR"dict_string_mem_required = %d\n", GLOBALS->dict_string_mem_required_lxt_c_1));
+DEBUG(fprintf(stderr, LXTHDR"dict_16_offset = %d\n", GLOBALS->dict_16_offset_lxt_c_1));
+DEBUG(fprintf(stderr, LXTHDR"dict_24_offset = %d\n", GLOBALS->dict_24_offset_lxt_c_1));
+DEBUG(fprintf(stderr, LXTHDR"dict_32_offset = %d\n", GLOBALS->dict_32_offset_lxt_c_1));
 
 fprintf(stderr, LXTHDR"Dictionary compressed MVL2 change records detected...\n");
 
@@ -409,7 +409,7 @@ zhandle = gzdopen(dup(GLOBALS->fd_lxt_c_1), "rb");
 decmem = malloc_2(total_mem = GLOBALS->dict_string_mem_required_lxt_c_1);
 
 rc=gzread(zhandle, decmem, total_mem);
-DEBUG(printf(LXTHDR"section offs for name decompression = %08x of len %d\n", offs, dict_string_mem_required));
+DEBUG(printf(LXTHDR"section offs for name decompression = %08x of len %d\n", offs, GLOBALS->dict_num_entries_lxt_c_1));
 DEBUG(printf(LXTHDR"Decompressed size is %d bytes (vs %d)\n", rc, total_mem));	
 if(rc!=total_mem) { fprintf(stderr, LXTHDR"decompression size disparity  %d bytes (vs %d)\n", rc, total_mem); exit(255); }
 
@@ -419,7 +419,7 @@ for(i=0;i<GLOBALS->dict_num_entries_lxt_c_1;i++)
 	{
 	GLOBALS->dict_string_mem_array_lxt_c_1[i]=pnt;
 	pnt+=(strlen(pnt)+1);
-	DEBUG(printf(LXTHDR"Dict %d: '1%s'\n", i, dict_string_mem_array[i]));
+	DEBUG(printf(LXTHDR"Dict %d: '1%s'\n", i, GLOBALS->dict_string_mem_array_lxt_c_1[i]));
 	}
 
 gzclose(zhandle);
@@ -542,7 +542,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	GLOBALS->mvlfacs_lxt_c_2[i].len=(node_block[i].lsi>node_block[i].msi)?(node_block[i].lsi-node_block[i].msi+1):(node_block[i].msi-node_block[i].lsi+1);
 
 	if(GLOBALS->mvlfacs_lxt_c_2[i].len>GLOBALS->lt_len_lxt_c_1) GLOBALS->lt_len_lxt_c_1 = GLOBALS->mvlfacs_lxt_c_2[i].len;
-	DEBUG(printf(LXTHDR"%s[%d:%d]\n", mvlfacs[i].f_name, node_block[i].msi, node_block[i].lsi));
+	DEBUG(printf(LXTHDR"%s[%d:%d]\n", f_name[i], node_block[i].msi, node_block[i].lsi));
 
 	offs+=0x10;
 	}
@@ -597,9 +597,9 @@ if(GLOBALS->time_table_offset_lxt_c_1)
 	{
 	offs = GLOBALS->time_table_offset_lxt_c_1;
 
-	DEBUG(printf(LXTHDR"Time table position: %08x\n", time_table_offset + 12));
+	DEBUG(printf(LXTHDR"Time table position: %08x\n", GLOBALS->time_table_offset_lxt_c_1 + 12));
 	GLOBALS->total_cycles_lxt_c_2=get_32(offs+0);
-	DEBUG(printf(LXTHDR"Total cycles: %d\n", total_cycles));
+	DEBUG(printf(LXTHDR"Total cycles: %d\n", GLOBALS->total_cycles_lxt_c_2));
 
 	if(GLOBALS->ztime_table_size_lxt_c_1)
 		{
@@ -631,10 +631,10 @@ if(GLOBALS->time_table_offset_lxt_c_1)
 		}
 
 	GLOBALS->first_cycle_lxt_c_2=get_32(offs);
-	DEBUG(printf(LXTHDR"First cycle: %d\n", first_cycle));
+	DEBUG(printf(LXTHDR"First cycle: %d\n", GLOBALS->first_cycle_lxt_c_2));
 	GLOBALS->last_cycle_lxt_c_2=get_32(offs+4);
-	DEBUG(printf(LXTHDR"Last cycle: %d\n", last_cycle));
-	DEBUG(printf(LXTHDR"Total cycles (actual): %d\n", last_cycle-first_cycle+1));
+	DEBUG(printf(LXTHDR"Last cycle: %d\n", GLOBALS->last_cycle_lxt_c_2));
+	DEBUG(printf(LXTHDR"Total cycles (actual): %d\n", GLOBALS->last_cycle_lxt_c_2-GLOBALS->first_cycle_lxt_c_2+1));
 	
 	/* rebuild time table from its deltas... */
 
@@ -669,10 +669,10 @@ if(GLOBALS->time_table_offset_lxt_c_1)
 	{
 	offs = GLOBALS->time_table_offset64_lxt_c_1;
 
-	DEBUG(printf(LXTHDR"Time table position: %08x\n", time_table_offset64 + 20));
+	DEBUG(printf(LXTHDR"Time table position: %08x\n", GLOBALS->time_table_offset64_lxt_c_1 + 20));
 
 	GLOBALS->total_cycles_lxt_c_2=(TimeType)((unsigned int)get_32(offs+0));
-	DEBUG(printf(LXTHDR"Total cycles: %d\n", total_cycles));
+	DEBUG(printf(LXTHDR"Total cycles: %d\n", GLOBALS->total_cycles_lxt_c_2));
 
 	if(GLOBALS->ztime_table_size_lxt_c_1)
 		{
@@ -704,10 +704,10 @@ if(GLOBALS->time_table_offset_lxt_c_1)
 		}
 
 	GLOBALS->first_cycle_lxt_c_2=get_64(offs);
-	DEBUG(printf(LXTHDR"First cycle: %d\n", first_cycle));
+	DEBUG(printf(LXTHDR"First cycle: %d\n", GLOBALS->first_cycle_lxt_c_2));
 	GLOBALS->last_cycle_lxt_c_2=get_64(offs+8);
-	DEBUG(printf(LXTHDR"Last cycle: %d\n", last_cycle));
-	DEBUG(printf(LXTHDR"Total cycles (actual): %lld\n", last_cycle-first_cycle+1));
+	DEBUG(printf(LXTHDR"Last cycle: %d\n", GLOBALS->last_cycle_lxt_c_2));
+	DEBUG(printf(LXTHDR"Total cycles (actual): %lld\n", GLOBALS->last_cycle_lxt_c_2-GLOBALS->first_cycle_lxt_c_2+1));
 	
 	/* rebuild time table from its deltas... */
 
@@ -771,7 +771,6 @@ if(GLOBALS->sync_table_offset_lxt_c_1)
 		chg=get_32(offs);  offs+=4;
 		if(chg>maxchg) {maxchg=chg; maxindx=i; }
 		GLOBALS->lastchange[i]=chg;
-		DEBUG(printf(LXTHDR"Changes: %d '%s' %08x\n", i, mvlfacs[i].f_name, chg));
 		}
 
 	if(GLOBALS->zsync_table_size_lxt_c_1)
@@ -784,8 +783,6 @@ if(GLOBALS->sync_table_offset_lxt_c_1)
 #endif
 		}
 
-	DEBUG(printf(LXTHDR"Maxchange at: %08x for symbol '%s' of len %d\n", maxchg, mvlfacs[maxindx].f_name,  mvlfacs[maxindx].len));
-
 	GLOBALS->maxchange_lxt_c_1=maxchg;
 	GLOBALS->maxindex_lxt_c_1=maxindx;
 	}
@@ -1448,7 +1445,7 @@ if(get_byte(GLOBALS->f_len_lxt_c_1-1)!=LT_TRLID)
 	}
 
 DEBUG(printf(LXTHDR"Loading LXT '%s'...\n", fname));
-DEBUG(printf(LXTHDR"Len: %d\n", (unsigned int)f_len));
+DEBUG(printf(LXTHDR"Len: %d\n", (unsigned int)GLOBALS->f_len_lxt_c_1));
 
 /* SPLASH */                            splash_create();
 
@@ -1535,7 +1532,7 @@ if(!GLOBALS->facname_offset_lxt_c_1)
 	}
 
 GLOBALS->numfacs=get_32(GLOBALS->facname_offset_lxt_c_1);
-DEBUG(printf(LXTHDR"Number of facs: %d\n", numfacs));
+DEBUG(printf(LXTHDR"Number of facs: %d\n", GLOBALS->numfacs));
 GLOBALS->mvlfacs_lxt_c_2=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
 GLOBALS->resolve_lxt_alias_to=(struct Node **)calloc_2(GLOBALS->numfacs,sizeof(struct Node *));
 GLOBALS->lastchange=(unsigned int *)calloc_2(GLOBALS->numfacs,sizeof(unsigned int));
@@ -2376,110 +2373,3 @@ np->curr = histent_tail;
 np->numhist++;
 }
 
-/*
- * $Id: lxt.c,v 1.24 2011/01/21 15:49:52 gtkwave Exp $
- * $Log: lxt.c,v $
- * Revision 1.24  2011/01/21 15:49:52  gtkwave
- * simplify strand coalesce routine and make same as FST's
- *
- * Revision 1.23  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.22  2011/01/07 20:17:10  gtkwave
- * remove redundant fields from struct fac
- *
- * Revision 1.21  2010/12/06 18:53:55  gtkwave
- * __asm directive error fix for AMD64
- *
- * Revision 1.20  2010/06/02 03:51:30  gtkwave
- * don't autocoalesce escape identifiers
- *
- * Revision 1.19  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.18  2010/03/13 21:38:16  gtkwave
- * fixed && used in logical operations for allocating ExtNode
- *
- * Revision 1.17  2010/03/13 19:16:00  gtkwave
- * removal of useless symbol->nextinaet code
- *
- * Revision 1.16  2010/03/12 21:12:39  gtkwave
- * removed lastchange field
- *
- * Revision 1.15  2010/03/12 20:37:15  gtkwave
- * removed resolve_lxt_alias_to field from struct fac
- *
- * Revision 1.14  2010/03/11 23:31:52  gtkwave
- * remove name field from struct fac
- *
- * Revision 1.13  2010/03/01 05:16:26  gtkwave
- * move compressed hier tree traversal to hierpack
- *
- * Revision 1.12  2010/01/23 03:21:11  gtkwave
- * hierarchy fixes when characters < "." are in the signal names
- *
- * Revision 1.11  2009/07/01 07:39:12  gtkwave
- * decorating hierarchy tree with module type info
- *
- * Revision 1.10  2009/04/30 03:24:40  gtkwave
- * added VCDNAM_ESCAPE cases to loader
- *
- * Revision 1.9  2008/12/27 23:29:42  gtkwave
- * lxt files for stray file descriptor on reload + clock compress fix
- *
- * Revision 1.8  2008/12/25 04:28:47  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.7  2008/10/12 02:56:20  gtkwave
- * fix for blackout regions
- *
- * Revision 1.6  2008/09/27 19:08:39  gtkwave
- * compiler warning fixes
- *
- * Revision 1.5  2008/07/22 18:46:16  gtkwave
- * add compressed hierarchy handling to lxt reader
- *
- * Revision 1.4  2008/07/18 18:22:58  gtkwave
- * fixes for aix
- *
- * Revision 1.3  2008/02/22 22:08:06  gtkwave
- * fix of previously undetected linear lxt reader bug involving integers
- *
- * Revision 1.2  2007/08/26 21:35:41  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.8  2007/08/25 19:42:39  gtkwave
- * lxt loader hardening
- *
- * Revision 1.1.1.1.2.7  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:54  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:47  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:21  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:39  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:28:03  gtkwave
- * Imported sources
- *
- * Revision 1.3  2007/04/29 04:13:49  gtkwave
- * changed anon union defined in struct Node to a named one as anon unions
- * are a gcc extension
- *
- * Revision 1.2  2007/04/20 02:08:13  gtkwave
- * initial release
- *
- */
-
