@@ -864,7 +864,7 @@ pr_renderhash (pr_context * prc, int x, TimeType tim)
   int rhs;
   int iter = 0;
   int s_ctx_iter;
-  int timearray_encountered = 0;
+  int timearray_encountered = (GLOBALS->ruler_step != 0);
 
   fhminus2 = GLOBALS->fontheight - 2;
 
@@ -889,7 +889,7 @@ pr_renderhash (pr_context * prc, int x, TimeType tim)
     return;
 
   rborder = (GLOBALS->tims.last - GLOBALS->tims.start) * GLOBALS->pxns;
-  DEBUG (printf ("Rborder: %lld, Wavewidth: %d\n", rborder, wavewidth));
+  DEBUG (printf ("Rborder: %lld, Wavewidth: %d\n", rborder, GLOBALS->wavewidth));
 
   if (rborder > GLOBALS->wavewidth)
     rborder = GLOBALS->wavewidth;
@@ -976,6 +976,7 @@ pr_rendertimes (pr_context * prc)
   char timebuff[32];
   gdouble realx;
   int s_ctx_iter;  
+  int timearray_encountered = 0;
 
   pr_renderblackout (prc);
 
@@ -995,6 +996,8 @@ pr_rendertimes (pr_context * prc)
       int y = GLOBALS->fontheight + 2;
       int oldx = -1;
 
+      timearray_encountered = 1;
+
       pos = bsearch_timechain (GLOBALS->tims.start);
     top:
       if ((pos >= 0) && (pos < GLOBALS->strace_ctx->timearray_size))
@@ -1038,9 +1041,54 @@ pr_rendertimes (pr_context * prc)
   GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = 0];
 	/**********/
 
+if(GLOBALS->ruler_step && !timearray_encountered)
+        {
+        TimeType rhs = (GLOBALS->tims.end > GLOBALS->tims.last) ? GLOBALS->tims.last : GLOBALS->tims.end;
+        TimeType low_x = (GLOBALS->tims.start - GLOBALS->ruler_origin) / GLOBALS->ruler_step;
+        TimeType high_x = (rhs - GLOBALS->ruler_origin) / GLOBALS->ruler_step;
+        TimeType iter_x, tm;
+        int y=GLOBALS->fontheight+2;
+        int oldx=-1;
+
+	pr_setgray (prc, 0.90);
+
+        for(iter_x = low_x; iter_x <= high_x; iter_x++)
+                {
+                tm = GLOBALS->ruler_step * iter_x +  GLOBALS->ruler_origin;
+                x=(tm-GLOBALS->tims.start)*GLOBALS->pxns;
+                if(oldx==x)
+                        {
+                        gdouble xd,offset,pixstep;
+                        TimeType newcurr;
+
+                        xd=x+1;  /* for pix time calc */
+
+                        pixstep=((gdouble)GLOBALS->nsperframe)/((gdouble)GLOBALS->pixelsperframe);
+                        newcurr=(TimeType)(offset=((gdouble)GLOBALS->tims.start)+(xd*pixstep));
+
+                        if(offset-newcurr>0.5)  /* round to nearest integer ns */
+                                {
+                                newcurr++;
+                                }
+
+                        low_x = (newcurr - GLOBALS->ruler_origin) / GLOBALS->ruler_step;
+                        if(low_x <= iter_x) low_x = (iter_x+1);
+                        iter_x = low_x;
+                        tm = GLOBALS->ruler_step * iter_x +  GLOBALS->ruler_origin;
+                        x=(tm-GLOBALS->tims.start)*GLOBALS->pxns;
+                        }
+
+		if(x>=GLOBALS->wavewidth) break;
+                oldx=x;
+		pr_draw_line (prc, x, y, x, GLOBALS->liney_max);
+                }
+        }
+
+	/**********/
+
   DEBUG (printf
 	 ("Ruler Start time: " TTFormat ", Finish time: " TTFormat "\n",
-	  tims.start, tims.end));
+	  GLOBALS->tims.start, GLOBALS->tims.end));
 
   x = 0;
   realx = 0;
@@ -2840,7 +2888,7 @@ pr_rendertraces (pr_context * prc)
 		  h = bsearch_node (t->n.nd, GLOBALS->tims.start - t->shift);
 		  DEBUG (printf
 			 ("Start time: " TTFormat ", Histent time: " TTFormat
-			  "\n", tims.start, (h->time + shift_timebase)));
+			  "\n", GLOBALS->tims.start, (h->time + GLOBALS->shift_timebase)));
 
 		  if (!t->n.nd->extvals)
 		    {
@@ -2858,11 +2906,11 @@ pr_rendertraces (pr_context * prc)
 
 		v = bsearch_vector (bv, GLOBALS->tims.start - t->shift);
 		DEBUG (printf
-			 ("Vector Trace: %s, %s\n", t->name, t->n.vec->name));
+			 ("Vector Trace: %s, %s\n", t->name, t->n.vec->bvname));
 		DEBUG (printf
 			 ("Start time: " TTFormat ", Vectorent time: "
-			  TTFormat "\n", tims.start,
-			  (v->time + shift_timebase)));
+			  TTFormat "\n", GLOBALS->tims.start,
+			  (v->time + GLOBALS->shift_timebase)));
 		if(i>=0) pr_draw_vptr_trace (prc, t, v, i);
 
                 if((bv->transaction_chain) && (t->flags & TR_TTRANSLATED))
@@ -3145,143 +3193,3 @@ print_mif_image (FILE * wave, gdouble px, gdouble py)
   print_image (&prc);
 }
 
-/*
- * $Id: print.c,v 1.40 2011/01/13 17:20:39 gtkwave Exp $
- * $Log: print.c,v $
- * Revision 1.40  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.39  2010/12/21 22:42:05  gtkwave
- * fix to mif_draw_string with respect to out of range character codes
- *
- * Revision 1.38  2010/09/20 22:36:31  gtkwave
- * fix renderhash aliasing errors due to lack of realx
- *
- * Revision 1.37  2010/07/16 16:12:38  gtkwave
- * pedantic warning fixes
- *
- * Revision 1.36  2010/04/14 18:45:37  gtkwave
- * allow data values for secondary transaction traces
- *
- * Revision 1.35  2010/04/14 04:21:46  gtkwave
- * update populateBuffer() usage
- *
- * Revision 1.34  2010/04/10 03:32:00  gtkwave
- * allow transaction traces to scroll off top of screen yet still be visible
- *
- * Revision 1.33  2010/04/09 20:52:33  gtkwave
- * add extension traces for extension transactions
- *
- * Revision 1.32  2010/04/01 03:10:58  gtkwave
- * time warp fixes
- *
- * Revision 1.31  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.30  2010/03/24 23:05:10  gtkwave
- * added RealToBits menu option
- *
- * Revision 1.29  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.28  2010/03/02 18:30:07  gtkwave
- * fix for analog stretch traces when expanded then collapsed
- *
- * Revision 1.27  2010/02/22 17:15:11  gtkwave
- * add y-coord clamping to avoid integer round off errors
- *
- * Revision 1.26  2010/02/21 05:15:16  gtkwave
- * analog drawing fix for clipping + overdraw
- *
- * Revision 1.25  2010/02/07 20:16:34  gtkwave
- * experiment with adding line clipping to analog rendering
- *
- * Revision 1.24  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.23  2010/01/19 17:50:40  gtkwave
- * updated print rendering to match wavewindow marker lock adds
- *
- * Revision 1.22  2009/06/26 19:56:18  gtkwave
- * add arrowheads to all impulse arrows
- *
- * Revision 1.21  2009/06/25 22:12:30  gtkwave
- * convert event impulses to strict 1/0 activity values regardless of val
- *
- * Revision 1.20  2009/06/25 18:31:19  gtkwave
- * added event types for VCD+FST and impulse arrows on event types
- *
- * Revision 1.19  2008/12/31 22:20:12  gtkwave
- * adding more tcl commands
- *
- * Revision 1.18  2008/12/25 04:14:11  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.17  2008/12/11 21:08:15  gtkwave
- * allow support for marker names which are strings
- *
- * Revision 1.16  2008/10/12 02:56:20  gtkwave
- * fix for blackout regions
- *
- * Revision 1.15  2008/02/08 02:26:36  gtkwave
- * anti-aliased font support add
- *
- * Revision 1.14  2008/01/28 23:08:50  gtkwave
- * added infinite scaling define in currenttime.h
- *
- * Revision 1.13  2008/01/27 23:54:05  gtkwave
- * right side margin NaN fix
- *
- * Revision 1.12  2008/01/27 01:21:05  gtkwave
- * make transition to/from inf/-inf a square wave when interpolated
- *
- * Revision 1.11  2008/01/26 19:13:34  gtkwave
- * replace NaN trapezoids with NaN boxes
- *
- * Revision 1.10  2008/01/26 05:02:14  gtkwave
- * added parallelogram rendering for nans
- *
- * Revision 1.9  2008/01/25 23:29:23  gtkwave
- * modify analog slightly for nan and inf handling
- *
- * Revision 1.8  2008/01/25 04:10:15  gtkwave
- * added new resizing options to menu
- *
- * Revision 1.7  2008/01/24 20:19:39  gtkwave
- * analog rendering fixes
- *
- * Revision 1.6  2008/01/23 04:49:32  gtkwave
- * more tweaking of interpolated+step mode (use snap dots)
- *
- * Revision 1.5  2008/01/23 02:05:44  gtkwave
- * added interpolated + step mode
- *
- * Revision 1.4  2008/01/22 20:11:47  gtkwave
- * track and hold experimentation
- *
- * Revision 1.3  2008/01/21 16:54:04  gtkwave
- * some analog fixes for end of screen
- *
- * Revision 1.2  2007/08/26 21:35:43  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.3  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.2  2007/08/06 03:50:48  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.1  2007/08/05 02:27:22  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1  2007/05/30 04:27:28  gtkwave
- * Imported sources
- *
- * Revision 1.3  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.2  2007/04/20 02:08:13  gtkwave
- * initial release
- *
- */
