@@ -147,6 +147,13 @@ GLOBALS->cursor_snap=(val<=0)?0:val;
 return(0);
 }
 
+int f_disable_ae2_alias(char *str)
+{
+DEBUG(printf("f_disable_ae2_alias(\"%s\")\n",str));
+GLOBALS->disable_ae2_alias=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_disable_empty_gui(char *str)
 {
 DEBUG(printf("f_disable_empty_gui(\"%s\")\n",str));
@@ -505,6 +512,20 @@ GLOBALS->use_roundcaps=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_ruler_origin(char *str)
+{
+DEBUG(printf("f_ruler_origin(\"%s\")\n",str));
+GLOBALS->ruler_origin=atoi_64(str);
+return(0);
+}
+
+int f_ruler_step(char *str)
+{
+DEBUG(printf("f_ruler_step(\"%s\")\n",str));
+GLOBALS->ruler_step=atoi_64(str);
+return(0);
+}
+
 int f_use_scrollbar_only(char *str)
 {
 DEBUG(printf("f_use_scrollbar_only(\"%s\")\n",str));
@@ -742,6 +763,7 @@ static struct rc_entry rcitems[]=
 { "context_tabposition", f_context_tabposition },
 { "convert_to_reals", f_convert_to_reals },
 { "cursor_snap", f_cursor_snap },
+{ "disable_ae2_alias", f_disable_ae2_alias },
 { "disable_empty_gui", f_disable_empty_gui },
 { "disable_mouseover", f_disable_mouseover },
 { "disable_tooltips", f_disable_tooltips },
@@ -772,6 +794,8 @@ static struct rc_entry rcitems[]=
 { "lxt_clock_compress_to_z", f_lxt_clock_compress_to_z },
 { "page_divisor", f_page_divisor },
 { "ps_maxveclen", f_ps_maxveclen },
+{ "ruler_origin", f_ruler_origin },
+{ "ruler_step", f_ruler_step },
 { "scale_to_time_dimension", f_scale_to_time_dimension },
 { "show_base_symbols", f_show_base_symbols },
 { "show_grid", f_show_grid },
@@ -990,109 +1014,3 @@ errno=0;
 return;
 }
 
-/*
- * $Id: rc.c,v 1.27 2010/12/30 09:22:00 gtkwave Exp $
- * $Log: rc.c,v $
- * Revision 1.27  2010/12/30 09:22:00  gtkwave
- * added userprofile patch for win32
- *
- * Revision 1.26  2010/10/26 17:37:35  gtkwave
- * added initial_signal_window_width rc variable
- *
- * Revision 1.25  2010/06/13 20:38:00  gtkwave
- * added strace repeat count
- *
- * Revision 1.24  2010/05/06 15:57:52  gtkwave
- * enable_fast_exit now is enabled by default
- *
- * Revision 1.23  2010/03/10 18:14:13  gtkwave
- * Toggle Trace Hier fix (cache old value for more usability)
- *
- * Revision 1.22  2010/02/21 05:15:16  gtkwave
- * analog drawing fix for clipping + overdraw
- *
- * Revision 1.21  2010/01/22 07:28:28  gtkwave
- * change grid2 color to slate blue
- *
- * Revision 1.20  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.19  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.18  2009/03/26 23:53:22  gtkwave
- * added disable_empty_gui rc variable which reverts to old behavior
- *
- * Revision 1.17  2009/03/15 17:34:03  gtkwave
- * adjusted mdgray and dkgray brightness for better visibility when using
- * collapsed traces
- *
- * Revision 1.16  2009/01/12 04:17:39  gtkwave
- * added dynamic zoom for end for partial vcd
- *
- * Revision 1.15  2008/12/28 03:03:34  gtkwave
- * Added scale_to_time_dimension rc variable and menu options.
- *
- * Revision 1.14  2008/12/25 03:21:57  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.13  2008/12/04 19:21:00  gtkwave
- * added zoom_dynamic option for partial VCD loading
- *
- * Revision 1.12  2008/11/25 20:00:54  gtkwave
- * added use_scrollwheel_as_y rc variable
- *
- * Revision 1.11  2008/02/21 04:14:21  gtkwave
- * default color for X is red now
- *
- * Revision 1.10  2008/02/08 15:29:19  gtkwave
- * enabled pango font support for gtk2
- *
- * Revision 1.9  2008/01/08 23:03:36  gtkwave
- * added toolbar using use_toolbutton_interface rc variable
- *
- * Revision 1.8  2008/01/02 18:17:26  gtkwave
- * added standard click semantics with user_standard_clicking rc variable
- *
- * Revision 1.7  2007/12/29 20:19:33  gtkwave
- * added dynamic string updates for entrybox in pattern search and sst
- *
- * Revision 1.6  2007/12/17 18:49:32  gtkwave
- * added vlist_prepack rc variable which enables vlist_packer code
- *
- * Revision 1.5  2007/11/30 01:31:23  gtkwave
- * added vlist memory spill to disk code + fixed vcdload status bar on > 2GB
- *
- * Revision 1.4  2007/09/11 17:17:32  gtkwave
- * allow tab movement with context_tabposition rc variable
- *
- * Revision 1.3  2007/08/26 21:35:44  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:48  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:23  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.2  2007/07/23 23:13:08  gtkwave
- * adds for color tags in filtered trace data
- *
- * Revision 1.1.1.1  2007/05/30 04:27:37  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
-
