@@ -191,8 +191,6 @@ GET_WV_STRACE_CURWIN(widget);
 for(i=0;i<6;i++) GLOBALS->strace_ctx->logical_mutex[i]=0;
 which_char=(char *)which;
 *which_char=1;			/* mark our choice */
-
-DEBUG(printf("picked: %s\n", logical[which_char-logical_mutex]));
 }
 
 static void stype_clicked(GtkWidget *widget, gpointer back)
@@ -1674,26 +1672,26 @@ if(GLOBALS->strace_ctx->timearray)
 				nodes=t->n.vec->bits->nodes;
 				for(i=0;i<t->n.vec->bits->nnbits;i++)
 					{
-					int was_packed = 0;
+					int was_packed = HIER_DEPACK_STATIC;
 					char *namex;
 					if(nodes[i]->expansion)
 						{
 						namex = hier_decompress_flagged(nodes[i]->expansion->parent->nname, &was_packed);
 						mprintf(" (%d)%s",nodes[i]->expansion->parentbit, namex);
-						if(was_packed) free_2(namex);
+						/* if(was_packed) free_2(namex); ...not needed for HIER_DEPACK_STATIC */
 						}
 						else
 						{
 						namex = hier_decompress_flagged(nodes[i]->nname, &was_packed);
 						mprintf(" %s",nodes[i]->nname);
-						if(was_packed) free_2(namex);
+						/* if(was_packed) free_2(namex); ...not needed for HIER_DEPACK_STATIC */
 						}
 					}
 				mprintf("\n");
 				}
 				else
 				{
-				int was_packed = 0;
+				int was_packed = HIER_DEPACK_STATIC;
 				char *namex;
 
 				if(HasAlias(t))
@@ -1702,13 +1700,13 @@ if(GLOBALS->strace_ctx->timearray)
 						{
 						namex = hier_decompress_flagged(t->n.nd->expansion->parent->nname, &was_packed);
 						mprintf("+{%s} (%d)%s\n",t->name+2,t->n.nd->expansion->parentbit, namex);
-						if(was_packed) free_2(namex);
+						/* if(was_packed) free_2(namex); ...not needed for HIER_DEPACK_STATIC */
 						}
 						else
 						{
 						namex = hier_decompress_flagged(t->n.nd->nname, &was_packed);
 						mprintf("+{%s} %s\n",t->name+2,namex);
-						if(was_packed) free_2(namex);
+						/* if(was_packed) free_2(namex); ...not needed for HIER_DEPACK_STATIC */
 						}
 					}
 					else
@@ -1717,13 +1715,13 @@ if(GLOBALS->strace_ctx->timearray)
 						{
 						namex = hier_decompress_flagged(t->n.nd->expansion->parent->nname, &was_packed);
 						mprintf("(%d)%s\n",t->n.nd->expansion->parentbit, namex);
-						if(was_packed) free_2(namex);
+						/* if(was_packed) free_2(namex); ...not needed for HIER_DEPACK_STATIC */
 						}
 						else
 						{
 						namex = hier_decompress_flagged(t->n.nd->nname, &was_packed);
 						mprintf("%s\n",namex);
-						if(was_packed) free_2(namex);
+						/* if(was_packed) free_2(namex); ...not needed for HIER_DEPACK_STATIC*/
 						}
 					}
 				}
@@ -1736,103 +1734,3 @@ if(GLOBALS->strace_ctx->timearray)
 	}
 }
 
-/*
- * $Id: strace.c,v 1.24 2011/01/13 17:20:39 gtkwave Exp $
- * $Log: strace.c,v $
- * Revision 1.24  2011/01/13 17:20:39  gtkwave
- * rewrote hierarchy / facility packing code
- *
- * Revision 1.23  2010/10/02 18:58:55  gtkwave
- * ctype.h compiler warning fixes (char vs int)
- *
- * Revision 1.22  2010/06/13 20:38:00  gtkwave
- * added strace repeat count
- *
- * Revision 1.21  2010/04/01 03:10:58  gtkwave
- * time warp fixes
- *
- * Revision 1.20  2010/03/31 20:41:03  gtkwave
- * nbits versus nnbits fix
- *
- * Revision 1.19  2010/03/24 23:05:10  gtkwave
- * added RealToBits menu option
- *
- * Revision 1.18  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.17  2010/03/10 04:00:07  gtkwave
- * fixed compiler warnings for 64-bit
- *
- * Revision 1.16  2010/02/24 17:35:35  gtkwave
- * gtk1 compile fixes
- *
- * Revision 1.15  2010/01/22 16:51:21  gtkwave
- * fixes to ensure WAVE_NUM_STRACE_WINDOWS is more maintainable
- *
- * Revision 1.14  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.13  2010/01/18 16:23:27  gtkwave
- * clock count fix (>= rather than > in endcap check for loop break)
- *
- * Revision 1.12  2009/12/24 20:55:27  gtkwave
- * warnings cleanups
- *
- * Revision 1.11  2009/09/14 03:00:08  gtkwave
- * bluespec code integration
- *
- * Revision 1.10  2009/07/07 20:12:53  gtkwave
- * convert hex capitalization to match verilog
- *
- * Revision 1.9  2009/03/09 23:29:12  gtkwave
- * fixed memory access violation and added comprehensive option.
- *
- * Revision 1.8  2008/07/01 18:51:07  gtkwave
- * compiler warning fixes for amd64
- *
- * Revision 1.7  2007/12/31 17:11:58  gtkwave
- * fixed backward seek bug in pattern/edge search
- *
- * Revision 1.6  2007/12/30 04:27:39  gtkwave
- * added edge buttons to main window
- *
- * Revision 1.5  2007/12/29 20:19:33  gtkwave
- * added dynamic string updates for entrybox in pattern search and sst
- *
- * Revision 1.4  2007/09/12 17:26:45  gtkwave
- * experimental ctx_swap_watchdog added...still tracking down mouse thrash crashes
- *
- * Revision 1.3  2007/09/10 18:08:49  gtkwave
- * tabs selection can swap dynamically based on external window focus
- *
- * Revision 1.2  2007/08/26 21:35:45  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.7  2007/08/18 21:51:57  gtkwave
- * widget destroys and teardown of file formats which use external loaders
- * and are outside of malloc_2/free_2 control
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:49  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:23  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:01  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:24  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
-
