@@ -266,7 +266,7 @@ if(!GLOBALS->facs_are_sorted)
 
 				for(i=0;i<GLOBALS->numfacs;i++)
 				        {
-				        int was_packed;
+				        int was_packed = HIER_DEPACK_STATIC;
 				        char *hfacname = NULL;
 		
 				        hfacname = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -281,7 +281,7 @@ if(!GLOBALS->facs_are_sorted)
 						s2++;
 						}
 	
-				        if(was_packed) { free_2(hfacname); }
+				        /* if(was_packed) { free_2(hfacname); } ...not needed with HIER_DEPACK_STATIC */
 					if(mat) { break; }
 				        }
 				}
@@ -297,7 +297,7 @@ if(!GLOBALS->facs_are_sorted)
 			mat = 0;
 			for(i=0;i<GLOBALS->numfacs;i++)
 			        {
-			        int was_packed;
+			        int was_packed = HIER_DEPACK_STATIC;
 			        char *hfacname = NULL;
 	
 			        hfacname = hier_decompress_flagged(GLOBALS->facs[i]->name, &was_packed);
@@ -306,7 +306,7 @@ if(!GLOBALS->facs_are_sorted)
 					mat = 1;
 					}
 	
-			        if(was_packed) { free_2(hfacname); }
+			        /* if(was_packed) { free_2(hfacname); } ...not needed with HIER_DEPACK_STATIC */
 				if(mat)
 					{
 					sr = GLOBALS->facs[i];
@@ -321,66 +321,3 @@ if(!GLOBALS->facs_are_sorted)
 	}
 }
 
-/*
- * $Id: symbol.c,v 1.13 2010/11/19 06:47:16 gtkwave Exp $
- * $Log: symbol.c,v $
- * Revision 1.13  2010/11/19 06:47:16  gtkwave
- * use PJE0 macro for unuser error return on judy function calls
- *
- * Revision 1.12  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.11  2010/03/17 13:46:56  gtkwave
- * cast long to pointer to avoid warnings in Judy1Set
- *
- * Revision 1.10  2010/03/16 21:01:10  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.9  2010/03/15 15:57:28  gtkwave
- * only allocate hash when necessary
- *
- * Revision 1.8  2010/03/15 03:14:53  gtkwave
- * deallocated symbol hash table after no longer needed
- *
- * Revision 1.7  2010/03/14 20:12:28  gtkwave
- * rename next hash pointer in struct symbol
- *
- * Revision 1.6  2010/01/23 21:26:38  gtkwave
- * additional fix for escaped names w/optimization
- *
- * Revision 1.5  2010/01/23 03:21:11  gtkwave
- * hierarchy fixes when characters < "." are in the signal names
- *
- * Revision 1.4  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.3  2010/01/22 01:00:03  gtkwave
- * fix for bsearch_facs fail when $ is in name at same pos as . in another
- *
- * Revision 1.2  2007/08/26 21:35:45  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.4  2007/08/25 19:43:46  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.3  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.2  2007/08/06 03:50:49  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.1  2007/08/05 02:27:23  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1  2007/05/30 04:27:26  gtkwave
- * Imported sources
- *
- * Revision 1.3  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
-
