@@ -71,7 +71,7 @@ for(;;)
 	{
 	ch=*(s++);
 
-	if((ch==GLOBALS->hier_delimeter) || (ch == '|'))
+	if(((ch==GLOBALS->hier_delimeter) || (ch == '|')) && (*s)) /* added && null check to allow possible . at end of name */
 		{
 		*(pnt)=0;	
 		GLOBALS->module_len_tree_c_1 = pnt - GLOBALS->module_tree_c_1;
@@ -87,6 +87,56 @@ for(;;)
 }
 
 
+/*
+ * generate unique hierarchy pointer faster that sprintf("%p")
+ * use 7-bit string to generate less characters
+ */
+#ifdef _WAVE_HAVE_JUDY
+static int gen_hier_string(char *dest, void *pnt)
+{
+unsigned long p = (unsigned long)(pnt);
+char *dest_copy = dest;
+
+while(p)
+	{
+	*(dest++) = (p & 0x7f) | 0x80;
+	p >>= 7;
+	}
+*(dest++) = '.';
+
+return(dest - dest_copy);
+}
+#endif
+
+
+/*
+ * decorated module cleanup (if judy active)
+ */
+int decorated_module_cleanup(void)
+{
+#ifdef _WAVE_HAVE_JUDY
+if(GLOBALS->sym_tree)
+	{
+	JudySLFreeArray(&GLOBALS->sym_tree, PJE0);
+	}
+
+if(GLOBALS->sym_tree_addresses)
+	{
+	int rcValue;
+	Word_t Index = 0;
+
+	for (rcValue = Judy1First(GLOBALS->sym_tree_addresses, &Index, PJE0); rcValue != 0; rcValue = Judy1Next(GLOBALS->sym_tree_addresses, &Index, PJE0))
+        	{
+        	((struct tree *)Index)->children_in_gui = 0;
+	        }
+
+	Judy1FreeArray(&GLOBALS->sym_tree_addresses, PJE0);
+	}
+
+#endif
+return(1);
+}
+
 /*
  * decorated module add
  */
@@ -94,6 +144,9 @@ void allocate_and_decorate_module_tree_node(unsigned char ttype, const char *sco
 {
 struct tree *t;
 int mtyp = WAVE_T_WHICH_UNDEFINED_COMPNAME;
+#ifdef _WAVE_HAVE_JUDY
+char str[2048];
+#endif
 
 if(compname && compname[0] && strcmp(scopename, compname))
 	{
@@ -109,18 +162,74 @@ if(GLOBALS->treeroot)
 	{
 	if(GLOBALS->mod_tree_parent)
 		{
-		t = GLOBALS->mod_tree_parent->child;
-		while(t)
+#ifdef _WAVE_HAVE_JUDY
+		if(GLOBALS->mod_tree_parent->children_in_gui)
 			{
-			if(!strcmp(t->name, scopename))
+			PPvoid_t PPValue;
+			/* find with judy */
+			int len = gen_hier_string(str, GLOBALS->mod_tree_parent);
+			strcpy(str+len, scopename);
+			PPValue = JudySLIns(&GLOBALS->sym_tree, (uint8_t *)str, PJE0);
+			if(*PPValue)
 				{
-				GLOBALS->mod_tree_parent = t;
+				GLOBALS->mod_tree_parent = *PPValue;
 				return;
 				}
-			t = t->next;
+
+			t = talloc_2(sizeof(struct tree) + scopename_len);
+			*PPValue = t;
+			goto t_allocated;
 			}
+			else
+			{
+			int dep = 0;
+#endif
+			t = GLOBALS->mod_tree_parent->child;
+			while(t)
+				{
+				if(!strcmp(t->name, scopename))
+					{
+					GLOBALS->mod_tree_parent = t;
+					return;
+					}
+				t = t->next;
+#ifdef _WAVE_HAVE_JUDY
+				dep++;
+#endif
+				}
+
+#ifdef _WAVE_HAVE_JUDY
+			if(dep >= FST_TREE_SEARCH_NEXT_LIMIT)
+				{
+				PPvoid_t PPValue;
+				int len = gen_hier_string(str, GLOBALS->mod_tree_parent);
+				GLOBALS->mod_tree_parent->children_in_gui = 1; /* "borrowed" for tree build */
+				t = GLOBALS->mod_tree_parent->child;
+
+				Judy1Set ((Pvoid_t)&GLOBALS->sym_tree_addresses, (Word_t)GLOBALS->mod_tree_parent, PJE0);
+				/* assemble judy based on scopename + GLOBALS->mod_tree_parent pnt */
+				while(t)
+					{
+					strcpy(str+len, t->name);
+					PPValue = JudySLIns(&GLOBALS->sym_tree, (uint8_t *)str, PJE0);
+					*PPValue = t;
+
+					t = t->next;
+					}
+
+				strcpy(str+len, scopename);
+				PPValue = JudySLIns(&GLOBALS->sym_tree, (uint8_t *)str, PJE0);
+				t = talloc_2(sizeof(struct tree) + scopename_len);
+				*PPValue = t;
+				goto t_allocated;
+				}
+			}
+#endif
 
 		t = talloc_2(sizeof(struct tree) + scopename_len);
+#ifdef _WAVE_HAVE_JUDY
+t_allocated:
+#endif
 		strcpy(t->name, scopename);
 		t->kind = ttype;
 		t->t_which = mtyp;
@@ -558,8 +667,12 @@ GLOBALS->facs2_tree_c_1 = NULL;
 void build_tree_from_name(const char *s, int which)
 {
 struct tree *t, *nt;
-struct tree *tchain, *tchain_iter;
+struct tree *tchain = NULL, *tchain_iter;
 struct tree *prevt;
+#ifdef _WAVE_HAVE_JUDY
+PPvoid_t PPValue = NULL;
+char str[2048];
+#endif
 
 if(s==NULL || !s[0]) return;
 
@@ -579,9 +692,32 @@ rs:		s=get_module_name(s);
 			continue;
 			}
 
+#ifdef _WAVE_HAVE_JUDY
+rescan:
+		if(prevt && prevt->children_in_gui)
+			{
+			/* find with judy */
+			int len = gen_hier_string(str, prevt);
+			strcpy(str+len, GLOBALS->module_tree_c_1);
+			PPValue = JudySLIns(&GLOBALS->sym_tree, (uint8_t *)str, PJE0);
+			if(*PPValue)
+				{
+				t = *PPValue;
+				prevt = t;
+				t = t->child;
+				continue;
+				}
+
+			goto construct;
+			}
+#endif
+
 		tchain = tchain_iter = t;
 		if(s && t)
 			{
+#ifdef _WAVE_HAVE_JUDY
+			int dep = 0;
+#endif
 		      	nt = t->next;
 		      	while(nt)
 				{
@@ -602,9 +738,37 @@ rs:		s=get_module_name(s);
 
 				tchain_iter = nt;
 				nt = nt->next;
+#ifdef _WAVE_HAVE_JUDY
+				dep++;
+#endif
 				}
+
+#ifdef _WAVE_HAVE_JUDY
+			if(prevt && (dep >= FST_TREE_SEARCH_NEXT_LIMIT))
+				{
+				int len = gen_hier_string(str, prevt);
+				prevt->children_in_gui = 1; /* "borrowed" for tree build */
+				t = prevt->child;
+
+				Judy1Set ((Pvoid_t)&GLOBALS->sym_tree_addresses, (Word_t)prevt, PJE0);
+				/* assemble judy based on scopename + prevt pnt */
+				while(t)
+					{
+					strcpy(str+len, t->name);
+					PPValue = JudySLIns(&GLOBALS->sym_tree, (uint8_t *)str, PJE0);
+					*PPValue = t;
+
+					t = t->next;
+					}
+
+				goto rescan; /* this level of hier is built, now do insert */
+				}
+#endif
 			}
 
+#ifdef _WAVE_HAVE_JUDY
+construct:
+#endif
 		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
 		memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
@@ -612,6 +776,13 @@ rs:		s=get_module_name(s);
 			{
 			nt->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 
+#ifdef _WAVE_HAVE_JUDY
+			if(prevt && prevt->children_in_gui)
+				{
+				*PPValue = nt;
+				}
+#endif
+
 			if(prevt)				/* make first in chain */
 				{
 				nt->next = prevt->child;
@@ -805,75 +976,3 @@ if(!GLOBALS->hier_grouping)
 
 #endif
 
-/*
- * $Id: tree.c,v 1.16 2011/01/23 21:55:54 gtkwave Exp $
- * $Log: tree.c,v $
- * Revision 1.16  2011/01/23 21:55:54  gtkwave
- * more optimizations
- *
- * Revision 1.15  2011/01/21 22:40:28  gtkwave
- * pass string lengths from api directly to code to avoid length calculations
- *
- * Revision 1.14  2011/01/19 16:18:19  gtkwave
- * fix for large allocations of tree alloc
- *
- * Revision 1.13  2011/01/19 06:36:31  gtkwave
- * added tree allocation pool when misaligned structs are enabled
- *
- * Revision 1.12  2011/01/18 02:38:35  gtkwave
- * added extra spacing between component type name for readability
- *
- * Revision 1.11  2011/01/18 00:00:12  gtkwave
- * preliminary tree component support
- *
- * Revision 1.10  2011/01/17 19:24:21  gtkwave
- * tree modifications to support decorated internal hierarchy nodes
- *
- * Revision 1.9  2010/09/23 22:04:55  gtkwave
- * added incremental SST build code
- *
- * Revision 1.8  2009/07/02 18:50:47  gtkwave
- * decorate VCD module trees with type info, add move to front to buildname
- *
- * Revision 1.7  2009/07/01 21:58:32  gtkwave
- * more GHW module type adds for icons in hierarchy window
- *
- * Revision 1.6  2009/07/01 18:22:35  gtkwave
- * added VHDL (GHW) instance types as icons
- *
- * Revision 1.5  2009/07/01 16:47:47  gtkwave
- * move decorated module alloc routine to tree.c
- *
- * Revision 1.4  2009/07/01 07:39:12  gtkwave
- * decorating hierarchy tree with module type info
- *
- * Revision 1.3  2008/12/26 20:47:59  gtkwave
- * fix for stack overflow crash on dumpfiles with very many signals
- *
- * Revision 1.2  2007/08/26 21:35:46  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.5  2007/08/25 19:43:46  gtkwave
- * header cleanups
- *
- * Revision 1.1.1.1.2.4  2007/08/21 22:35:40  gtkwave
- * prelim tree state merge
- *
- * Revision 1.1.1.1.2.3  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.2  2007/08/06 03:50:49  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.1  2007/08/05 02:27:24  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1  2007/05/30 04:27:35  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
-
