@@ -142,22 +142,8 @@ static char *tokens[]={ "var", "end", "scope", "upscope",
 
 /******************************************************************/
 
-
-#ifdef DEBUG_PRINTF
-static char *vartypes[]={ "event", "parameter",
-                "integer", "real", "real_parameter", "realtime", "reg", "supply0",
-                "supply1", "time", "tri", "triand", "trior",
-                "trireg", "tri0", "tri1", "wand", "wire", "wor", "port", "in", "out", "inout",
-                "$end", "", "", "", ""};  
-#endif
-
-
 #define NUM_VTOKENS 23  
 
-
-/******************************************************************/
-
-
 /******************************************************************/
  
 
@@ -1088,7 +1074,7 @@ for(;;)
 					break;
 				}
 
-			DEBUG(fprintf(stderr,"TIMESCALE: "TTFormat" %cs\n",time_scale, time_dimension));
+			DEBUG(fprintf(stderr,"TIMESCALE: "TTFormat" %cs\n",GLOBALS->time_scale, GLOBALS->time_dimension));
 			sync_end(NULL);
 			}
 			break;
@@ -1128,7 +1114,7 @@ for(;;)
 					}
 
 				build_slisthier();
-				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
+				DEBUG(fprintf(stderr, "SCOPE: %s\n",GLOBALS->slisthier));
 				}
 			sync_end(NULL);
 			break;
@@ -1159,7 +1145,7 @@ for(;;)
 					s=s->next;
 					}
 				build_slisthier();
-				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
+				DEBUG(fprintf(stderr, "SCOPE: %s\n",GLOBALS->slisthier));
 				}
 				else
 				{
@@ -1542,9 +1528,6 @@ for(;;)
 				}
 			GLOBALS->numsyms_vcd_partial_c_2++;
 
-			DEBUG(fprintf(stderr,"VAR %s %d %s %s[%d:%d]\n",
-				vartypes[v->vartype], v->size, v->id, v->name, 
-					v->msi, v->lsi));
 			goto bail;
 			err:
 			if(v)
@@ -2588,168 +2571,3 @@ if(GLOBALS->partial_vcd)
 gtkwave_main_iteration();
 }
 
-/*
- * $Id: vcd_partial.c,v 1.45 2011/01/21 22:40:29 gtkwave Exp $
- * $Log: vcd_partial.c,v $
- * Revision 1.45  2011/01/21 22:40:29  gtkwave
- * pass string lengths from api directly to code to avoid length calculations
- *
- * Revision 1.44  2011/01/18 00:00:12  gtkwave
- * preliminary tree component support
- *
- * Revision 1.43  2011/01/16 07:56:08  gtkwave
- * inlining of character get functions
- *
- * Revision 1.42  2010/12/19 07:59:10  gtkwave
- * warnings fixes
- *
- * Revision 1.41  2010/12/14 21:26:06  gtkwave
- * support XL-style identifiers for optimization detection in sym build
- *
- * Revision 1.40  2010/12/14 19:53:14  gtkwave
- * scaled back id multiplier from 95 to 94
- *
- * Revision 1.39  2010/12/12 18:32:45  gtkwave
- * add "string" variable type to parsing of vcd variable declarations
- *
- * Revision 1.38  2010/12/10 20:13:13  gtkwave
- * added escape codes to string record parsing
- *
- * Revision 1.37  2010/11/19 06:47:16  gtkwave
- * use PJE0 macro for unuser error return on judy function calls
- *
- * Revision 1.36  2010/06/02 03:51:30  gtkwave
- * don't autocoalesce escape identifiers
- *
- * Revision 1.35  2010/06/02 03:23:04  gtkwave
- * disable autocoalesce if Icarus Verilog is detected
- *
- * Revision 1.34  2010/04/04 19:09:57  gtkwave
- * rename name->bvname in struct BitVector for easier grep tracking
- *
- * Revision 1.33  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.32  2010/03/18 17:12:37  gtkwave
- * pedantic warning cleanups
- *
- * Revision 1.31  2010/03/17 17:32:45  gtkwave
- * use calloc'd memory for SL iterator initialization
- *
- * Revision 1.30  2010/03/16 21:01:12  gtkwave
- * remove selected member of struct symbol
- *
- * Revision 1.29  2010/03/15 16:40:56  gtkwave
- * fixed kick_partial_vcd to handle maxtime scrolling over markertime
- *
- * Revision 1.28  2010/03/15 15:57:29  gtkwave
- * only allocate hash when necessary
- *
- * Revision 1.27  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.26  2010/03/13 19:48:53  gtkwave
- * remove nextinaet field and replace with temp symchain
- *
- * Revision 1.25  2010/03/13 07:56:41  gtkwave
- * removed unused h field in struct symbol
- *
- * Revision 1.24  2010/02/22 21:13:36  gtkwave
- * added "realtime" VCD variable
- *
- * Revision 1.23  2010/02/18 23:06:04  gtkwave
- * change name of main iteration loop calls
- *
- * Revision 1.22  2009/12/22 20:00:41  gtkwave
- * warnings fixes
- *
- * Revision 1.21  2009/07/07 19:46:03  gtkwave
- * make evcd->vcd conversion table const
- *
- * Revision 1.20  2009/07/07 15:48:37  gtkwave
- * EVCD "f" value fix (should be z not x)
- *
- * Revision 1.19  2009/07/06 21:41:36  gtkwave
- * evcd support issues
- *
- * Revision 1.18  2009/07/02 18:50:47  gtkwave
- * decorate VCD module trees with type info, add move to front to buildname
- *
- * Revision 1.17  2009/06/25 21:21:12  gtkwave
- * crash fix for zero bit wide events
- *
- * Revision 1.16  2009/06/25 18:31:19  gtkwave
- * added event types for VCD+FST and impulse arrows on event types
- *
- * Revision 1.15  2009/04/30 01:30:53  gtkwave
- * VCD parser fix for double subscripted nets
- *
- * Revision 1.14  2009/04/23 04:57:38  gtkwave
- * ported shmidcat and partial vcd loader function to mingw
- *
- * Revision 1.13  2009/01/12 18:46:00  gtkwave
- * added marker nail-down during partial vcd w dynamic zoom
- *
- * Revision 1.12  2009/01/12 04:17:39  gtkwave
- * added dynamic zoom for end for partial vcd
- *
- * Revision 1.11  2008/12/25 03:52:32  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.10  2008/12/04 19:21:00  gtkwave
- * added zoom_dynamic option for partial VCD loading
- *
- * Revision 1.9  2008/10/12 02:56:20  gtkwave
- * fix for blackout regions
- *
- * Revision 1.8  2008/09/17 04:33:38  gtkwave
- * support for smaller timescales in VCD files
- *
- * Revision 1.7  2008/07/18 18:46:11  gtkwave
- * bitblasted vector relinking fix, disable hier pack in legacy+partial vcdload
- *
- * Revision 1.6  2008/07/18 18:23:06  gtkwave
- * fixes for aix
- *
- * Revision 1.5  2008/07/18 17:27:01  gtkwave
- * adding hierpack code
- *
- * Revision 1.4  2008/07/12 22:54:12  gtkwave
- * array of wires malformed vcd dump load abort fixed
- *
- * Revision 1.3  2007/09/11 02:12:50  gtkwave
- * context locking in busy spinloops (gtk_main_iteration() calls)
- *
- * Revision 1.2  2007/08/26 21:35:46  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.6  2007/08/07 03:18:55  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.5  2007/08/06 03:50:50  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.4  2007/08/05 02:27:28  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1.2.3  2007/07/31 03:18:02  kermin
- * Merge Complete - I hope
- *
- * Revision 1.1.1.1.2.2  2007/07/28 19:50:40  kermin
- * Merged in the main line
- *
- * Revision 1.1.1.1  2007/05/30 04:27:26  gtkwave
- * Imported sources
- *
- * Revision 1.4  2007/05/28 00:55:06  gtkwave
- * added support for arrays as a first class dumpfile datatype
- *
- * Revision 1.3  2007/04/29 06:07:28  gtkwave
- * fixed memory leaks in vcd parser
- *
- * Revision 1.2  2007/04/20 02:08:17  gtkwave
- * initial release
- *
- */
-
