@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2005-2010.
+ * Copyright (c) Tony Bybell 2005-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -547,7 +547,7 @@ recurse_build(vt, &hp_clone);
 
 for(i=0;i<nodecnt;i++)
 	{
-	int was_packed = 0;
+	int was_packed = HIER_DEPACK_STATIC;
 	char *hname = hier_decompress_flagged(GLOBALS->hp_vcd_saver_c_1[i]->item->nname, &was_packed);
 	char *netname = lxt ? hname : output_hier(hname);
 
@@ -611,10 +611,7 @@ for(i=0;i<nodecnt;i++)
 			}
 		}
 
-	if(was_packed)
-		{
-		free_2(hname);
-		}
+	/* if(was_packed) { free_2(hname); } ...not needed for HIER_DEPACK_STATIC */
 	}
 
 row_data = malloc_2(max_len + 1);
@@ -932,7 +929,28 @@ if(*pnt2 == '\\')
 	}
 	else
 	{
-	while((*pnt2!='.')&&(*pnt2)) pnt2++;
+	/* while((*pnt2!='.')&&(*pnt2)) pnt2++; ... does not handle dot at end of name */
+
+	while(*pnt2)
+		{
+		if(*pnt2!='.')
+			{
+			pnt2++;
+			continue;
+			}
+			else
+			{
+			if(!*(pnt2+1))	/* if dot is at end of name */
+				{
+				pnt2++;
+				continue;
+				}
+				else
+				{
+				break;
+				}
+			}
+		}
 	}
 
 s=(char *)calloc_2(1,(len=pnt2-pnt)+1);
@@ -1557,87 +1575,3 @@ GLOBALS->f_vcd_saver_c_1 = NULL;
 return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
 }
 
-/*
- * $Id: vcd_saver.c,v 1.22 2010/12/19 07:59:10 gtkwave Exp $
- * $Log: vcd_saver.c,v $
- * Revision 1.22  2010/12/19 07:59:10  gtkwave
- * warnings fixes
- *
- * Revision 1.21  2010/12/12 18:32:45  gtkwave
- * add "string" variable type to parsing of vcd variable declarations
- *
- * Revision 1.20  2010/12/10 20:13:13  gtkwave
- * added escape codes to string record parsing
- *
- * Revision 1.19  2010/08/26 18:42:23  gtkwave
- * added support for transaction filters in mingw
- *
- * Revision 1.18  2010/07/16 16:12:38  gtkwave
- * pedantic warning fixes
- *
- * Revision 1.17  2010/06/23 05:45:34  gtkwave
- * warnings fixes
- *
- * Revision 1.16  2010/04/01 20:07:35  gtkwave
- * timescale multiplier fix for transactions
- *
- * Revision 1.15  2010/03/31 15:42:47  gtkwave
- * added preliminary transaction filter support
- *
- * Revision 1.14  2010/03/24 23:05:10  gtkwave
- * added RealToBits menu option
- *
- * Revision 1.13  2010/03/14 07:09:49  gtkwave
- * removed ExtNode and merged with Node
- *
- * Revision 1.12  2010/01/22 02:10:49  gtkwave
- * added second pattern search capability
- *
- * Revision 1.11  2009/07/07 20:12:53  gtkwave
- * convert hex capitalization to match verilog
- *
- * Revision 1.10  2009/04/30 19:18:41  gtkwave
- * added space before final brackets in VCD writers
- *
- * Revision 1.9  2009/04/15 21:39:50  gtkwave
- * use XL-style identifier sequencing for VCD identifiers
- *
- * Revision 1.8  2008/12/25 03:52:32  gtkwave
- * -Wshadow warning fixes
- *
- * Revision 1.7  2008/12/16 19:28:20  gtkwave
- * more warnings cleanups
- *
- * Revision 1.6  2008/12/06 19:55:53  gtkwave
- * more adds to the timinganalyzer output writer
- *
- * Revision 1.5  2008/12/05 21:05:19  gtkwave
- * changed lower limit for time compare in "X" generation
- *
- * Revision 1.4  2008/12/05 19:44:08  gtkwave
- * prelim support for timinganalyzer file format export
- *
- * Revision 1.3  2008/07/18 17:27:01  gtkwave
- * adding hierpack code
- *
- * Revision 1.2  2007/08/26 21:35:46  gtkwave
- * integrated global context management from SystemOfCode2007 branch
- *
- * Revision 1.1.1.1.2.3  2007/08/07 03:18:56  kermin
- * Changed to pointer based GLOBAL structure and added initialization function
- *
- * Revision 1.1.1.1.2.2  2007/08/06 03:50:50  gtkwave
- * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
- * generated structs, etc.
- *
- * Revision 1.1.1.1.2.1  2007/08/05 02:27:28  kermin
- * Semi working global struct
- *
- * Revision 1.1.1.1  2007/05/30 04:27:54  gtkwave
- * Imported sources
- *
- * Revision 1.2  2007/04/20 02:08:18  gtkwave
- * initial release
- *
- */
-
